/*
                             *******************
******************************* C SOURCE FILE ********************************
**                           *******************                            **
**                                                                          **
**  Project   : TEK                                                         **
**  Filename  : TEK_AnalogToDigital.C                                       **
**  Version   : -.- (PCB : )                                                **
**  Date      : ----.--.--                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  (c) 2015 TE Connectivity Ltd. All Rights Reserved                       **
**                                                                          **
**                     Tyco Electronics AMP Korea Ltd.                      **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -
Date        : - --, ----
Revised by  : TEK
Description : Original version.

*/

#define _TEK_ANALOG_TO_DIGITAL_C_SRC

//#pragma MESSAGE DISABLE C1420 /* WARNING C1420: Result of function-call is ignored */
//#pragma MESSAGE DISABLE C4002 /* WARNING C4002: Result not used is ignored */
//#pragma MESSAGE DISABLE C4301 /* INFORMATION C4301: Inline expansion done for function call */

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include "TEK_AnalogToDigital.h"
#if defined (Def_USE_SCI_DEB)
	#include "TEK_Monitor.h"
#endif

#pragma DATA_SEG ECU_TEK_ANALOG_TO_DIGITAL_DATA
#pragma CODE_SEG ECU_TEK_ANALOG_TO_DIGITAL_CODE

/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/
#define Def_ADC_CHANNEL_MAX			( 12U )
#define Def_ADC_RESULT_BUF_MAX		( 10U )

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/


/****************************************************************************/
/**                                                                        **/
/**                      PROTOTYPES OF LOCAL FUNCTIONS                     **/
/**                                                                        **/
/****************************************************************************/
typedef struct 
{
	byte m_u8BufIdx;
	word m_u16MinValue;
	word m_u16MaxValue;
	word m_u16SumValue;
	word m_u16AvrValue;
	word m_u16ArrResultBuf[Def_ADC_RESULT_BUF_MAX];
}Tds_ADCResults;

static void TEK_ADC_UpdateResultData( byte l_u8UpdateOrder );

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      GLOBAL VARIABLES                                  **/
/**                                                                        **/
/****************************************************************************/
Tds_ADCResults gs_tdsAdcResult[Def_AD_CH_ID_MAX] = 
{
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* Int1 */	
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* Int4 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN0 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN1 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN2 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN3 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN4 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN5 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN6 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN7 */
	{0U, 0U, 0U, 0U, 0U, {0U}},	/* AN8 */
	{0U, 0U, 0U, 0U, 0U, {0U}}	/* AN9 */
};

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/

/*--------------------------------------------------------------------------*/
/* Function  | Analog to Digital (ECU layer)                                */
/* Name      | TEK_AnalogToDigital_Init                                     */
/*--------------------------------------------------------------------------*/
/* Parameter | Nothing                                                      */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
void TEK_AnalogToDigital_Init( void )
{
	/* run-time(Result buffer : 10) : 623usec */
	
	byte l_u8nIdx;

	for( l_u8nIdx=0U; l_u8nIdx < Def_ADC_RESULT_BUF_MAX/*10U*/; l_u8nIdx++ ) 				/* Result buffer total is 10 */
	{
		TEK_ADC_Start();
		TEK_ADC_UpdateResultData(Def_AD_UPDATE_ALL);
	}
	
  	return;
}

/*--------------------------------------------------------------------------*/
/* Function  | ADC conversion control by main every 5msec                   */
/* Name      | TEK_AnalogToDigital_Main                                     */
/*--------------------------------------------------------------------------*/
/* Parameter | Nothing                                                      */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
void TEK_AnalogToDigital_Main( void )
{
	/* AD Conversion time : 30usec */
	
	/*PTT_PTT0 = 1U;*/
	TEK_ADC_Start();
	TEK_ADC_UpdateResultData(Def_AD_UPDATE_ALL);
	/*PTT_PTT0 = 0U;*/
	return;
}


/*--------------------------------------------------------------------------*/
/* Function  | Start ADC conversion                                         */
/* Name      | TEK_ADC_Start                                                */
/*--------------------------------------------------------------------------*/
/* Parameter | Nothing                                                      */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
void TEK_ADC_Start( void )
{
#if 0
	/* AD Conversion time : 30usec */
	
	/*PTT_PTT0 = 1U;*/
	ADC0CONIF = ADC0CONIF;      					/* clear flag */
	ADC0FLWCTL_RSTA = 1U;							/* Trigger a Restart event */
	
	while( ADC0CONIF_EOL_IF==0U ) { /*Nothing*/ }  	/* wait for EOL_IF set */
	ADC0CONIF = ADC0CONIF;      					/* clear flag */
	/*PTT_PTT0 = 0U;*/
#else
	/* AD Conversion time : 30usec */
	
	PTP_PTP6 = 1U;
	ADC0CONIF = ADC0CONIF;      					/* clear flag */
	ADC0FLWCTL_RSTA = 1U;							/* Trigger a Restart event */


	while( ADC0CONIF_EOL_IF==0U ) { /*Nothing*/ }  	/* wait for EOL_IF set */
	
	
	PTP_PTP6 = 0U;
	
	ADC0CONIF = ADC0CONIF;      					/* clear flag */

#endif
	return;
}

/*--------------------------------------------------------------------------*/
/* Function  | Start ADC conversion                                         */
/* Name      | TEK_ADC_UpdateResultData                                     */
/*--------------------------------------------------------------------------*/
/* Parameter | l_u8UpdateOrder                                              */
/*           | - 0xFFU(Def_AD_UPDATE_ALL), 0x00U~0x11U (Each AD Channel)    */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
static void TEK_ADC_UpdateResultData( byte l_u8UpdateOrder )
{
	/* run-time(Update All channel) : around(about) 31usec */
	/* run-time(Update single channel) : around(about) 3usec */
	
	byte l_u8nIdx;
	
	if( l_u8UpdateOrder == Def_AD_UPDATE_ALL )	/* All AD result update */ 
	{
		for( l_u8nIdx=0U; l_u8nIdx<Def_AD_CH_ID_MAX/*CSL-12U*/; l_u8nIdx++ )	/* ADC (CSL) Channel is 12 */
		{
			gs_tdsAdcResult[l_u8nIdx].m_u16ArrResultBuf[gs_tdsAdcResult[l_u8nIdx].m_u8BufIdx] = gs_u16ArrAdcRVL[l_u8nIdx];	/* Update ADC Result */
			if( gs_tdsAdcResult[l_u8nIdx].m_u8BufIdx < (Def_ADC_RESULT_BUF_MAX - 1U) ) { gs_tdsAdcResult[l_u8nIdx].m_u8BufIdx += 1U; }
			else { gs_tdsAdcResult[l_u8nIdx].m_u8BufIdx = 0U; }
		}
	}
	else	/* AD Channel update for the request channel */  
	{
		if( l_u8UpdateOrder < Def_AD_CH_ID_MAX )	 
		{
			gs_tdsAdcResult[l_u8UpdateOrder].m_u16ArrResultBuf[gs_tdsAdcResult[l_u8UpdateOrder].m_u8BufIdx] = gs_u16ArrAdcRVL[l_u8UpdateOrder];	/* Update ADC Result */
			if( gs_tdsAdcResult[l_u8UpdateOrder].m_u8BufIdx < (Def_ADC_RESULT_BUF_MAX - 1U) ) { gs_tdsAdcResult[l_u8UpdateOrder].m_u8BufIdx += 1U; }
			else { gs_tdsAdcResult[l_u8UpdateOrder].m_u8BufIdx = 0U; }
		}
		else { 
			/* Nothing */
			/* You can use this routine for coding check. */
		}
	}
	
	return;
}

/*--------------------------------------------------------------------------*/
/* Function  | Get ADC result                                               */
/* Name      | TEK_ADC_GetValue                                     		*/
/*--------------------------------------------------------------------------*/
/* Parameter | AD channel index (0~11)                                      */
/*           | - 0x00U~0x11U (Each AD Channel)                              */
/* Return    | AD conversion result value with filtering                    */
/*--------------------------------------------------------------------------*/
word TEK_ADC_GetValue_Filtering( byte l_u8AD_CH_ID )
{
	/* run-time : around(about) 43usec */
	
	byte l_u8nIdx;
	word l_u16RetValue; 		
	
	if( l_u8AD_CH_ID < Def_AD_CH_ID_MAX ) 
	{
		gs_tdsAdcResult[l_u8AD_CH_ID].m_u16SumValue = 0U;
		
		for( l_u8nIdx=0U; l_u8nIdx < Def_ADC_RESULT_BUF_MAX/*10U*/; l_u8nIdx++ ) 				/* Result buffer total is 10 */
		{
			if( l_u8nIdx == 0U ) /* If first conversion data */
			{
				gs_tdsAdcResult[l_u8AD_CH_ID].m_u16MinValue = gs_tdsAdcResult[l_u8AD_CH_ID].m_u16ArrResultBuf[l_u8nIdx];	
				gs_tdsAdcResult[l_u8AD_CH_ID].m_u16MaxValue = gs_tdsAdcResult[l_u8AD_CH_ID].m_u16ArrResultBuf[l_u8nIdx];
			}
			else {
				if( gs_tdsAdcResult[l_u8AD_CH_ID].m_u16ArrResultBuf[l_u8nIdx] < gs_tdsAdcResult[l_u8AD_CH_ID].m_u16MinValue )
					{ gs_tdsAdcResult[l_u8AD_CH_ID].m_u16MinValue = gs_tdsAdcResult[l_u8AD_CH_ID].m_u16ArrResultBuf[l_u8nIdx]; }
				if( gs_tdsAdcResult[l_u8AD_CH_ID].m_u16ArrResultBuf[l_u8nIdx] > gs_tdsAdcResult[l_u8AD_CH_ID].m_u16MaxValue ) 
					{ gs_tdsAdcResult[l_u8AD_CH_ID].m_u16MaxValue = gs_tdsAdcResult[l_u8AD_CH_ID].m_u16ArrResultBuf[l_u8nIdx]; }
			}
			gs_tdsAdcResult[l_u8AD_CH_ID].m_u16SumValue += gs_tdsAdcResult[l_u8AD_CH_ID].m_u16ArrResultBuf[l_u8nIdx];
		}
		
		/* calculate the adc result average data with min. and max. value filtering */
		gs_tdsAdcResult[l_u8AD_CH_ID].m_u16SumValue -= (gs_tdsAdcResult[l_u8AD_CH_ID].m_u16MinValue + gs_tdsAdcResult[l_u8AD_CH_ID].m_u16MaxValue);
		gs_tdsAdcResult[l_u8AD_CH_ID].m_u16AvrValue = ( gs_tdsAdcResult[l_u8AD_CH_ID].m_u16SumValue >> 3U );	/* x/8 */
		l_u16RetValue = gs_tdsAdcResult[l_u8AD_CH_ID].m_u16AvrValue; 
	}
	else { 
		l_u16RetValue = 0xFFFFU; 	/* initial set to invalid value */
									/* You can use this routine for coding check. */
	}	

	return (l_u16RetValue);
}

/*--------------------------------------------------------------------------*/
/* Function  | Get ADC result                                               */
/* Name      | TEK_ADC_GetValue                                     		*/
/*--------------------------------------------------------------------------*/
/* Parameter | AD channel index (0~11)                                      */
/*           | - 0x00U~0x11U (Each AD Channel)                              */
/* Return    | Most recently AD conversion value                            */
/*--------------------------------------------------------------------------*/
word TEK_ADC_GetValue( byte l_u8AD_CH_ID )
{
	word l_u16RetValue; 	
	
	if( l_u8AD_CH_ID < Def_AD_CH_ID_MAX ) { l_u16RetValue = gs_tdsAdcResult[l_u8AD_CH_ID].m_u16ArrResultBuf[gs_tdsAdcResult[l_u8AD_CH_ID].m_u8BufIdx]; }
	else { 
		l_u16RetValue = 0xFFFFU; 	/* initial set to invalid value */
									/* You can use this routine for coding check. */
	} 

	return ( l_u16RetValue );
}

#pragma DATA_SEG DEFAULT
#pragma CODE_SEG DEFAULT
/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/
