/*
                             *******************
******************************* C HEADER FILE ********************************
**                           *******************                            **
**                                                                          **
**  Project   : TEK                                                         **
**  Filename  : TEK_ECU_Config.H                                            **
**  Version   : -.- (PCB : )                                                **
**  Date      : ----.--.--                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  (c) 2015 TE Connectivity Ltd. All Rights Reserved                       **
**                                                                          **
**                     Tyco Electronics AMP Korea Ltd.                      **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -
Date        : - --, ----
Revised by  : TEK
Description : Original version.

*/

#ifndef _TEK_ECU_CONFIG_INCLUDED
#define _TEK_ECU_CONFIG_INCLUDED

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include "TEK_Lib_Defines.h"

/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/
/*----------------------------------------------------------------------------
  @ ECU configuration - TEK_MONITOR
----------------------------------------------------------------------------*/
/* Timeout value in ms - ex : 100(100ms) ===================================*/
#define TEK_MONITOR_TIME_SEC			  ( 1000 )  /* 1sec   */

/*----------------------------------------------------------------------------
  @ ECU configuration - TEK_MSDI
----------------------------------------------------------------------------*/
#if 0
	#define MC33978_JOB_ID			        ( en_SPI_JOB_0 )
	#define MC33978_SPI_CHAN		        ( SPI_CHAN_0 )		/* 0 or 1 or 2 */
	#define MC33978_CS_PORT             ( &PORTK )
	#define MC33978_CS_BIT	            ( u8g_Bit3 )
	
	#define MC33978_WAKE_PORT           ( PTP )
	#define MC33978_WAKE_BIT            ( u8g_Bit4 )
	
	/* MSDI Configuration =======================================================*/
	#define UNUSED_REG                  ( 0x00 )
	
	/* Device Configuration Register */
	#define DEV_CFG_CMD                 ( 0x03 )
	#define DEV_CFG_REG2                ( UNUSED_REG )  /* default(0x00) */
	#define DEV_CFG_REG1                ( 0x08 )        /* default(0x08) */
	#define DEV_CFG_REG0                ( 0x00 )        /* default(0x00) 0-Switch to Ground, 1-Switch to Battery */
	
	
	/* Tri-state SP Register */
	#define TRI_SP_CMD		              ( 0x05 )
	#define TRI_SP_REG2                 ( UNUSED_REG )  /* default(0x00) */
	#define TRI_SP_REG1                 ( UNUSED_REG )  /* default(0x00) */
	#define TRI_SP_EN_REG0              ( 0xFF )        /* default(0xFF) 1:high-impedance */
	#define TRI_SP_DI_REG0              ( 0x00 )
	
	/* Tri-state SG Register */
	#define TRI_SG_CMD		              ( 0x07 )
	#define TRI_SG_REG2                 ( UNUSED_REG )  /* default(0x00) */
	#define TRI_SG_EN_REG1              ( 0x3F )        /* default(0x3F) 1:high-impedance */
	#define TRI_SG_DI_REG1              ( 0x00 )
	#define TRI_SG_EN_REG0              ( 0xFF )        /* default(0xFF) 1:high-impedance */
	#define TRI_SG_DI_REG0              ( 0x00 )
	
	/* Wetting Current Levels ----------------------------------------------------
	bit2, bit1, bit0
	 0     0     0   - 2mA
	 0     0     1   - 6mA
	 0     1     0   - 8mA
	 0     1     1   - 10mA
	 1     0     0   - 12mA
	 1     0     1   - 14mA
	 1     1     0   - 16mA(default)
	 1     1     1   - 20mA
	----------------------------------------------------------------------------*/
	/* Wetting Current Level SP Register */
	#define WET_SP_CMD		              ( 0x09 )
	#define WET_SP_REG2		              ( 0x00 )        /* default(0xDB) */
	#define WET_SP_REG1		              ( 0x00 )        /* default(0x6D) */
	#define WET_SP_REG0		              ( 0x00 )        /* default(0xB6) */
	
	/* Wetting Current Level SG Register 0 */
	#define WET_SG0_CMD		              ( 0x0B )
	#define WET_SG0_REG2		            ( 0x00 )        /* default(0xDB) */
	#define WET_SG0_REG1		            ( 0x00 )        /* default(0x6D) */
	#define WET_SG0_REG0		            ( 0x00 )        /* default(0xB6) */
	
	/* Wetting Current Level SG Register 1 */
	#define WET_SG1_CMD		              ( 0x0D )
	#define WET_SG1_REG2		            ( 0x00 )        /* default(0x03) */
	#define WET_SG1_REG1		            ( 0x00 )        /* default(0x6D) */
	#define WET_SG1_REG0		            ( 0x00 )        /* default(0xB6) */
	
	#if defined ( ENABLE_MSDI_WAKE_UP_CONTROL )
	/* Wake-up Enable Register SP */
	#define WAKE_SP_CMD                 ( 0x21 )
	#define WAKE_SP_REG2                ( UNUSED_REG )  /* default(0x00) */
	#define WAKE_SP_REG1                ( UNUSED_REG )  /* default(0x00) */
	#define WAKE_SP_REG0                ( 0xFF )        /* default(0xFF) */
	
	/* Wake-up Enable Register SG */
	#define WAKE_SG_CMD                 ( 0x23 )
	#define WAKE_SG_REG2                ( UNUSED_REG )  /* default(0x00) */
	#define WAKE_SG_REG1                ( 0x3F )        /* default(0x3F) */
	#define WAKE_SG_REG0                ( 0xFF )        /* default(0xFF) */
	#endif
	
	/*----------------------------------------------------------------------------
	  @ ECU configuration - TEK_LSRS
	----------------------------------------------------------------------------*/
	#define TLE7240_JOB_ID			        ( en_SPI_JOB_1 )
	#define TLE7240_SPI_CHAN		        ( SPI_CHAN_0 )		/* 0 or 1 or 2 */
	#define TLE7240_CS_PORT             ( &PTS )
	#define TLE7240_CS_BIT	            ( u8g_Bit7 )
	
	#define TLE7240_RESET_PORT          ( PORTK )
	#define TLE7240_RESET_BIT           ( u8g_Bit7 )
#endif

/*----------------------------------------------------------------------------
  @ ECU configuration - TEK_AnlogToDigital
----------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
/* A/D Buffer Number                                                        */
/*--------------------------------------------------------------------------*/
#define AD_BUF_TURN_LH      ( 0 )
#define AD_BUF_TURN_RH      ( 1 )
#define AD_BUF_TAIL_LH      ( 2 )
#define AD_BUF_TAIL_RH      ( 3 )
#define AD_BUF_ROOM_LP      ( 4 )
#define AD_BUF_AMB_SNR      ( 5 )
#define AD_BUF_AUTO_LIGHT   ( 6 )
#define AD_BUF_BAT          ( 7 )
#define AD_BUF_IG1          ( 8 )
#define AD_BUF_MAX          ( 9 )
#define AD_BUF_ARRY_MAX     ( 3 )

/*--------------------------------------------------------------------------*/
/* A/D Channel Number                                                       */
/*--------------------------------------------------------------------------*/
#define AD_CH_BAT           ( 0 )
#define AD_CH_IG1           ( 1 )
#define AD_CH_TURN_LH       ( 2 )
#define AD_CH_TURN_RH       ( 2 )
#define AD_CH_TAIL_LH       ( 3 )
#define AD_CH_TAIL_RH       ( 3 )
#define AD_CH_ROOM_LP       ( 4 )
#define AD_CH_AMB_SNR       ( 5 )
#define AD_CH_AUTO_LIGHT    ( 6 )

/*--------------------------------------------------------------------------*/
/* A/D Battery Voltage                                                      */
/*--------------------------------------------------------------------------*/
#define BATT_CTRL_PORT            ( PTT )
#define BATT_CTRL_BIT             ( u8g_Bit1 )

#define ALS_CTRL_PORT             ( PORTE )
#define ALS_CTRL_BIT              ( u8g_Bit3 )

#define BSW_CTRL_PORT             ( PTH )
#define BSW_CTRL_BIT              ( u8g_Bit6 )

#define BatteryMonitoringOn()     ( setReg8Bits( BATT_CTRL_PORT, BATT_CTRL_BIT ) )
#define BatteryMonitoringOff()    ( clrReg8Bits( BATT_CTRL_PORT, BATT_CTRL_BIT ) )

#define AutolightMonitoringOn()   ( clrReg8Bits( ALS_CTRL_PORT, ALS_CTRL_BIT ) )
#define AutolightMonitoringOff()  ( setReg8Bits( ALS_CTRL_PORT, ALS_CTRL_BIT ) )

#define BrakeSwCtlOn()            ( clrReg8Bits( BSW_CTRL_PORT, BSW_CTRL_BIT ) )
#define BrakeSwCtlOff()           ( setReg8Bits( BSW_CTRL_PORT, BSW_CTRL_BIT ) )

#define u16s_DEFAULT_VOLTAGE      ( 13500 ) /* 13.5 V */
#define u16s_BATT_FAIL_VOLTAGE    ( 3500 )  /* 3.5 V  */

#define u16s_ADC_RES_VAL          ( 1024 )
#define u16s_EXTPOWER_VREF        ( 5000 )  /* 5V */
/*----------------------------------------------------------------------------
  u32s_BATT_SCALE = (((R1+R2)/R2)*100) * Vref
  517 = (((R1+R2)/R2)*100), u16s_EXTPOWER_VREF = Vref
----------------------------------------------------------------------------*/
#define u32s_BATT_SCALE         ( 517 * ( dword )u16s_EXTPOWER_VREF ) 

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/
/*----------------------------------------------------------------------------
  @ ECU configuration - TEK_Timer
----------------------------------------------------------------------------*/
/* Timer id ================================================================*/
typedef enum 
{
	en_TEK_MONITOR_TIMER = 0,
	en_MAX_NO_OF_TIMERS
}EN_TIMER_ID;

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/

#ifndef _TEK_ECU_CONFIG_C_SRC
#endif

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/

#endif

/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/
