/*
                             *******************
******************************* C SOURCE FILE ********************************
**                           *******************                            **
**                                                                          **
**  Project   : HYUNDAM-FPCM                                                **
**  Filename  : TEK_ADC.C                                                   **
**  Version   : -.- (PCB : )                                                **
**  Date      : ----.--.--                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  (c) 2015 TE Connectivity Ltd. All Rights Reserved                       **
**                                                                          **
**                     Tyco Electronics AMP Korea Ltd.                      **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -
Date        : - --, ----
Revised by  : JC.HAM
Description : Original version.

*/

#define _TEK_ADC_C_SRC

//#pragma MESSAGE DISABLE C1420 /* WARNING C1420: Result of function-call is ignored */
//#pragma MESSAGE DISABLE C4002 /* WARNING C4002: Result not used is ignored */
//#pragma MESSAGE DISABLE C4301 /* INFORMATION C4301: Inline expansion done for function call */

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include "TEK_ADC.h"

#pragma DATA_SEG MCU_TEK_ADC_DATA
#pragma CODE_SEG MCU_TEK_ADC_CODE

/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      PROTOTYPES OF LOCAL FUNCTIONS                     **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      GLOBAL VARIABLES                                  **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/

#pragma DATA_SEG DEFAULT               /* Select data segment "DEFAULT" */

#if 1
	#if 0
		const static unsigned long gs_u32ArrAdcCSL[Def_AD_CH_ID_MAX] __attribute__ ((aligned (4))) = {
	#else
		const unsigned long gs_u32ArrAdcCSL[Def_AD_CH_ID_MAX] __attribute__ ((aligned (4))) = {		
	#endif
		ADC_CSL_INT1, ADC_CSL_INT4, ADC_CSL_AN0, ADC_CSL_AN1, ADC_CSL_AN2, ADC_CSL_AN3, 
		ADC_CSL_AN4, ADC_CSL_AN5, ADC_CSL_AN6, ADC_CSL_AN7, ADC_CSL_AN8, ADC_CSL_AN9
	};	/* ADC Command Sequence Lists */
#else	
	const unsigned long gs_u32ArrAdcCSL[Def_AD_CH_ID_MAX] __attribute__ ((aligned (4))) = {		
		ADC_CSL_INT1, ADC_CSL_INT4, ADC_CSL_AN0, ADC_CSL_AN1, ADC_CSL_AN2, ADC_CSL_AN3, 
		ADC_CSL_AN4, ADC_CSL_AN5, ADC_CSL_AN6, ADC_CSL_AN7, ADC_CSL_AN8, ADC_CSL_AN9
	};	/* ADC Command Sequence Lists */
#endif
unsigned int gs_u16ArrAdcRVL[Def_AD_CH_ID_MAX]  __attribute__ ((aligned (4))) = {0U};	/* ADM Result Value Lists */

#pragma DATA_SEG MCU_TEK_ADC_DATA

static unsigned char index = 0U;

#if 0
	/* AD channel information 
	 * 0b00000 : Vrl
	 * 0b00001 : Vrh
	 * 0b00010 : (Vrh-Vrl)/2
	 * 0b00011~0b00111 : Reserved 
	 * 0b01000 : Interanl_0 (Reserved)
	 * 0b01001 : Interanl_1 (Chip temperature sensor Vth)
	 * 0b01010 : Interanl_2 (Flash Voltage VDDF)
	 * 0b01011 : Interanl_3 (Reserved)
	 * 0b01100 : Interanl_4 (Vsup)
	 * 0b01101 : Internal_5 (High voltage input port L0)
	 * 0b01110 : Internal_6 (High voltage input port L1)
	 * 0b01111 : Internal_7 (Reserved)
	 * 0b10000 : AN0
	 * 0b10001 : AN1
	 * 0b10010 : AN2
	 * 0b10011 : AN3 (P_SEN_VCC : Pressure sensor power)
	 * 0b10100 : AN4 (BTN8982TA_IS)
	 * 0b10101 : AN5
	 * 0b10110 : AN6
	 * 0b10111 : AN7
	 * 0b11000 : AN8 (P_SENS : Pressure sensor)
	 * 0b11001 : AN9
	 *  
	 */
#endif

/*--------------------------------------------------------------------------*/
/* Function  | Initialize TEK_ADC                                           */
/* Name      | TEK_ADC_Init                                                 */
/*--------------------------------------------------------------------------*/
/* Parameter | Nothing                                                      */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
void TEK_ADC_Init( void )
{
	unsigned long l_u32address;
	
	/* Configure ADC0 control */
	ADC0CTL_0 = 0x0DU;		/* Dual-access mode(ACC_CFG), Trigger mode(MOD_CFG) */
	ADC0CTL_1 = 0x00U;		/* Single CSL & RVL buffers(CSL_BMOD, RVL_BMOD), Normal access, No Auto-Restart after exit from STOP */ 
	ADC0STS = 0x00U;		/* Select CSL 0 and RVL 0 */
	ADC0TIM = 0x01U;		/* fADCCLK = fBUS/(2*(PRS+1)) = 32Mhz/(2*(1+1)) = 8Mhz */
	
	/*** ADC0CBP - ADC0 Command Base Pointer Register configuration ***/
	l_u32address = (unsigned long) &gs_u32ArrAdcCSL[0U];
	ADC0CBP_0 = (unsigned char) (l_u32address >> 16U);
	ADC0CBP_1 = (unsigned char) (l_u32address >> 8U);
	ADC0CBP_2 = (unsigned char) (l_u32address);
	
	/*** ADC0RBP - ADC0 Result Base Pointer Register configuration ***/
	l_u32address = (unsigned long) &gs_u16ArrAdcRVL[0U];
	ADC0RBP_0 = (unsigned char) (l_u32address >> 16U);
	ADC0RBP_1 = (unsigned char) (l_u32address >> 8U);
	ADC0RBP_2 = (unsigned char) (l_u32address);		
	
	/*** ADC0FMT - ADC0 Format Register ***/
	ADC0FMT = 0x82U;		/* 10-bit resolution, right justified */

	ADC0CONIF = ADC0CONIF;	/* ADC interrupt complete flag clear */

	BATE = 0x08U;			/* BATS VSUP ADC Connection Enable - Internal 4 */ 
	
	/* Start conversion -- ADC0 */
	ADC0CTL_0_ADC_EN = 1U;	/* Enable the ADC */
	
	return;
}

#pragma DATA_SEG DEFAULT
#pragma CODE_SEG DEFAULT
/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/
