/*
                             *******************
******************************* C HEADER FILE ********************************
**                           *******************                            **
**                                                                          **
**  Project   : HYUNDAM-FPCM                                                **
**  Filename  : TEK_ADC.H                                                   **
**  Version   : -.- (PCB : )                                                **
**  Date      : ----.--.--                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  (c) 2015 TE Connectivity Ltd. All Rights Reserved                       **
**                                                                          **
**                     Tyco Electronics AMP Korea Ltd.                      **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -
Date        : - --, ----
Revised by  : JC.HAM
Description : Original version.

*/

#ifndef _TEK_ADC_INCLUDED
#define _TEK_ADC_INCLUDED

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include "TEK_MCU_Config.h"

#pragma DATA_SEG MCU_TEK_ADC_DATA
#pragma CODE_SEG MCU_TEK_ADC_CODE
/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/
#define CMD_SEL_NORMAL			( 0U )		/* Normal conversion */
#define CMD_SEL_EOS				( 1U )		/* End of sequence */
#define CMD_SEL_EOL_A			( 2U )		/* End of list - Automatic wrap to top of CSL and Continue Conversion */
#define CMD_SEL_EOL				( 3U ) 		/* End of list - Wrap to top of CLS and: 
												- In "Restart mode" wait for Restart Event followed by a Trigger
												- In "Trigger mode" wait for Trigger or Restart Event */

#define CMD_SEL(x)					( (unsigned long) ( (x) & (0x03U) ) << (30U) )
#define INTFLG_SEL(x)				( (unsigned long) ( (x) & (0x0FU) ) << (24U) )
#define VRH_SEL(x)					( (unsigned long) ( (x) & (0x01U) ) << (23U) )
#define VRL_SEL(x)					( (unsigned long) ( (x) & (0x01U) ) << (22U) )
#define CH_SEL(x)					( (unsigned long) ( (x) & (0x3FU) ) << (16U) )
#define SMP(x)						( (unsigned long) ( (x) & (0x1FU) ) << (11U) )

#define ADC_CSL_INT1				( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(1U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x09U) )   	/* Internal 1 Temperature */
#define ADC_CSL_INT4				( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(2U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x0CU) )   	/* Internal 4 Vsup */
#define ADC_CSL_AN0					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(3U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x10U) )   	/* AN0 - Not use */
#define ADC_CSL_AN1					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(4U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x11U) )   	/* AN1 - Not use */
#define ADC_CSL_AN2					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(5U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x12U) )   	/* AN2 - Not use */
#define ADC_CSL_AN3					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(6U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x13U) )   	/* AN3 - Pressure sensor power */
#define ADC_CSL_AN4					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(7U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x14U) )   	/* AN4 - BTN8982TA_IS */
#define ADC_CSL_AN5					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(8U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x15U) )   	/* AN5 - Not use */
#define ADC_CSL_AN6					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(9U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x16U) )   	/* AN6 - Not use */
#define ADC_CSL_AN7					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(10U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x17U) )   /* AN7 - Not use */
#define ADC_CSL_AN8					( CMD_SEL(CMD_SEL_NORMAL)+INTFLG_SEL(11U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x18U) )   /* AN8 - Pressure sensor */
#define ADC_CSL_AN9					( CMD_SEL(CMD_SEL_EOL)+INTFLG_SEL(12U)+VRH_SEL(1U)+VRL_SEL(1U)+CH_SEL(0x19U) )   	/* AN9 - Not use */

#define Def_AD_UPDATE_ALL			( 0xFFU )	/* All ADC channels update */
#define Def_AD_CH_ID_INT1			( 0x00U )	/* Internal temperature for MCU chip */
#define Def_AD_CH_ID_Vsup			( 0x01U )	/* Vsup pin */
#define Def_AD_CH_ID_AN0			( 0x02U )	/* AN0 */
#define Def_AD_CH_ID_P_SENS_VCC		( 0x03U )	/* AN1 */
#define Def_AD_CH_ID_P_SENS			( 0x04U )	/* AN2 */
#define Def_AD_CH_ID_AN3			( 0x05U )	/* AN3 */
#define Def_AD_CH_ID_BTN8982_IS		( 0x06U )	/* AN4 */
#define Def_AD_CH_ID_AN5			( 0x07U )	/* AN5 */
#define Def_AD_CH_ID_AN6			( 0x08U )	/* AN6 */
#define Def_AD_CH_ID_AN7			( 0x09U )	/* AN7 */
#define Def_AD_CH_ID_AN8			( 0x0AU )	/* AN8 */
#define Def_AD_CH_ID_AN9			( 0x0BU )	/* AN9 */
#define Def_AD_CH_ID_MAX			( 0x0CU )	/* Max. Idx */

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/
#ifndef _TEK_PWM_C_SRC
#endif

#pragma DATA_SEG DEFAULT
	extern const unsigned long gs_u32ArrAdcCSL[];
	extern unsigned int gs_u16ArrAdcRVL[];
#pragma CODE_SEG MCU_TEK_ADC_CODE

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/
extern void TEK_ADC_Init( void );
/*extern void TEK_ADC_Start( void );*/ /* move to AnalogToDigital.c */	

#pragma DATA_SEG DEFAULT
#pragma CODE_SEG DEFAULT

#endif

/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/
