/*
                             *******************
******************************* C SOURCE FILE ********************************
**                           *******************                            **
**                                                                          **
**  Project   : HYUNDAM-FPCM                                                **
**  Filename  : TEK_DIO.C                                                   **
**  Version   : -.- (PCB : )                                                **
**  Date      : ----.--.--                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  (c) 2015 TE Connectivity Ltd. All Rights Reserved                       **
**                                                                          **
**                     Tyco Electronics AMP Korea Ltd.                      **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -.-
Date        : ----.--.--
Revised by  : JC.HAM
Description : Original version.

*/

#define _TEK_DIO_C_SRC

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include "TEK_DIO.h"

#pragma DATA_SEG MCU_TEK_DIO_DATA
#pragma CODE_SEG MCU_TEK_DIO_CODE
/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      PROTOTYPES OF LOCAL FUNCTIONS                     **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      GLOBAL VARIABLES                                  **/
/**                                                                        **/
/****************************************************************************/
/* Port data register address */
static volatile byte *u8sp_PortDataReg[ en_MAX_NO_OF_PORT ] =
{
	&PTE,
	&PTADH,
	&PTADL,
	&PTT,
	&PTS,
	&PTP,
	&PTJ,
	&PTIL		/* note: Port L only is input port */
};
/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/
/*--------------------------------------------------------------------------*/
/* Function  | Initialize all port                                          */
/* Name      | TEK_DIO_Init                                                 */
/*--------------------------------------------------------------------------*/
/* Parameter | Nothing                                                      */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
void TEK_DIO_Init( void )
{
	/* Initialization for Port E */
	setReg8( PTE , PORT_E_INIT );		/* Port Data Register */
	/*setReg8( PTIE , PORT_E_PT );*/	/* Port Input Register */
	setReg8( DDRE , PORT_E_DDR );		/* Port Direction Register - defined to DIO.h */
	setReg8( PERE , PORT_E_PER );		/* Port Pull Device Enable Register - reset value is 0x03 */
	setReg8( PPSE , PORT_E_PPS );		/* Port Polarity Select Register - reset value is 0x03 */
	/*setReg8( PIEE , PORT_E_PIE );*/
	/*setReg8( PIFE , PORT_E_PIF );*/
	/*setReg8( DIENE , PORT_E_DIEN );*/
	/*setReg8( RDRE , PORT_E_RDR );*/
	/*setReg8( WOME , PORT_E_WOM );*/
	
	/* Initialization for Port ADH - PAD8~PAD15 */
	setReg8( PTADH , PORT_ADH_INIT );
	/*setReg8( PTADH , PORT_ADH_PT );*/
	/*setReg8( PTIADH , PORT_ADH_DDR );*/
	setReg8( DDRADH , PORT_ADH_DDR );
	setReg8( PERADH , PORT_ADH_PER );
	setReg8( PPSADH , PORT_ADH_PPS );
	setReg8( PIEADH , PORT_ADH_PIE );
	setReg8( PIFADH , PORT_ADH_PIF );
	setReg8( DIENADH , PORT_ADH_DIEN );
	/*setReg8( RDRADH , PORT_ADH_RDR );*/
	/*setReg8( WOMADH , PORT_ADH_WOM );*/
	
	/* Initialization for Port ADL - PAD0~PAD7 */
	setReg8( PTADL , PORT_ADL_INIT );
	/*setReg8( PTADH , PORT_ADL_PT );*/
	/*setReg8( PTIADH , PORT_ADL_DDR );*/
	setReg8( DDRADL , PORT_ADL_DDR );
	setReg8( PERADL , PORT_ADL_PER );
	setReg8( PPSADL , PORT_ADL_PPS );
	setReg8( PIEADL , PORT_ADL_PIE );
	setReg8( PIFADL , PORT_ADL_PIF );
	setReg8( DIENADL , PORT_ADL_DIEN );
	/*setReg8( RDRADL , PORT_ADL_RDR );*/
	/*setReg8( WOMADL , PORT_ADL_WOM );*/
	
	/* Initialization for Port T */
	setReg8( PTT , PORT_T_INIT );		/* Port Data Register */
	/*setReg8( PTIT , PORT_T_PT );*/	/* Port Input Register */
	setReg8( DDRT , PORT_T_DDR );		/* Port Direction Register - defined to DIO.h */
	setReg8( PERT , PORT_T_PER );		/* Port Pull Device Enable Register - reset value is 0x03 */
	setReg8( PPST , PORT_T_PPS );		/* Port Polarity Select Register - reset value is 0x03 */
	/*setReg8( PIET , PORT_T_PIE );*/
	/*setReg8( PIFT , PORT_T_PIF );*/
	/*setReg8( DIENT , PORT_T_DIEN );*/
	/*setReg8( RDRT , PORT_T_RDR );*/
	/*setReg8( WOMT , PORT_T_WOM );*/
	
	/* Initialization for Port S */
	setReg8( PTS , PORT_S_INIT );		/* Port Data Register */
	/*setReg8( PTIS , PORT_T_PT );*/	/* Port Input Register */
	setReg8( DDRS , PORT_S_DDR );		/* Port Direction Register - defined to DIO.h */
	setReg8( PERS , PORT_S_PER );		/* Port Pull Device Enable Register - reset value is 0x03 */
	setReg8( PPSS , PORT_S_PPS );		/* Port Polarity Select Register - reset value is 0x03 */
	setReg8( PIES , PORT_S_PIE );
	setReg8( PIFS , PORT_S_PIF );
	/*setReg8( DIENS , PORT_S_DIEN );*/
	/*setReg8( RDRS , PORT_S_RDR );*/
	/*setReg8( WOMS , PORT_S_WOM );*/

	/* Initialization for Port P */
	setReg8( PTP , PORT_P_INIT );		/* Port Data Register */
	/*setReg8( PTIP , PORT_P_PT );*/	/* Port Input Register */
	setReg8( DDRP , PORT_P_DDR );		/* Port Direction Register - defined to DIO.h */
	setReg8( PERP , PORT_P_PER );		/* Port Pull Device Enable Register - reset value is 0x03 */
	setReg8( PPSP , PORT_P_PPS );		/* Port Polarity Select Register - reset value is 0x03 */
	setReg8( PIEP , PORT_P_PIE );
	setReg8( PIFP , PORT_P_PIF );
	/*setReg8( DIENP , PORT_P_DIEN );*/
	setReg8( RDRP , PORT_P_RDR );
	/*setReg8( WOMP , PORT_P_WOM );*/

	/* Initialization for Port J */
	setReg8( PTJ , PORT_J_INIT );		/* Port Data Register */
	/*setReg8( PTIJ , PORT_J_PT );*/	/* Port Input Register */
	setReg8( DDRJ , PORT_J_DDR );		/* Port Direction Register - defined to DIO.h */
	setReg8( PERJ , PORT_J_PER );		/* Port Pull Device Enable Register - reset value is 0x03 */
	setReg8( PPSJ , PORT_J_PPS );		/* Port Polarity Select Register - reset value is 0x03 */
	/*setReg8( PIEJ , PORT_J_PIE );*/
	/*setReg8( PIFJ , PORT_J_PIF );*/
	/*setReg8( DIENJ , PORT_J_DIEN );*/
	/*setReg8( RDRJ , PORT_J_RDR );*/
	setReg8( WOMJ , PORT_J_WOM );

	/* Initialization for Port L */
	/*setReg8( PTL , PORT_L_INIT );*/	/* Port Data Register */
	/*setReg8( PTIL , PORT_L_PT );*/	/* Port Input Register */
	/*setReg8( DDRL , PORT_L_DDR );*/	/* Port Direction Register - defined to DIO.h */
	/*setReg8( PERL , PORT_L_PER );*/	/* Port Pull Device Enable Register - reset value is 0x03 */
	setReg8( PPSL , PORT_L_PPS );		/* Port Polarity Select Register - reset value is 0x03 */
	setReg8( PIEL , PORT_L_PIE );
	setReg8( PIFL , PORT_L_PIF );
	setReg8( DIENL , PORT_L_DIEN );
	/*setReg8( RDRL , PORT_L_RDR );*/
	/*setReg8( WOML , PORT_L_WOM );*/

	return;
}

/*--------------------------------------------------------------------------*/
/* Function  | Returns the value of the specified DIO channel               */
/* Name      | TEK_DIO_ReadChannel                                          */
/*--------------------------------------------------------------------------*/
/* Parameter | u8_ChannelId - ID of DIO channel                             */
/* Return    | 1 - physical level of corresponding pin is high              */
/*           | 0 - physical level of corresponding pin is low               */
/*--------------------------------------------------------------------------*/
byte TEK_DIO_ReadChannel( byte u8_ChannelId )
{
	volatile byte *u8p_PortReg; /* port data register */
	byte u8_PortId;
	byte u8_BitOffset;
	byte u8_Mask;
	byte u8_ReadChannelValue = 0U;	
	
	u8_PortId = ( byte )( u8_ChannelId / 8U );
	u8_BitOffset = ( byte )( u8_ChannelId % 8U );
	u8_Mask = ( byte )( 0x01U << u8_BitOffset );

	if( u8_PortId < en_MAX_NO_OF_PORT )
	{
		u8p_PortReg = u8sp_PortDataReg[ u8_PortId ];
		
		if( ( ( *u8p_PortReg ) & u8_Mask ) != 0U ) 
		{ 
		  u8_ReadChannelValue = 1U;
		}
	}
	
	return ( u8_ReadChannelValue );
}

/*--------------------------------------------------------------------------*/
/* Function  | Set a level of a channel                                     */
/* Name      | TEK_DIO_WriteChannel                                         */
/*--------------------------------------------------------------------------*/
/* Parameter | u8_ChannelId - ID of DIO channel                             */
/*           | u8_Level - Level                                             */
/*           | Level                                                        */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
void TEK_DIO_WriteChannel( byte u8_ChannelId, byte u8_Level )
{
	volatile byte *u8p_PortReg; /* port data register */
	byte u8_PortId;
	byte u8_BitOffset;
	byte u8_Mask;
	
	u8_PortId = ( byte )( u8_ChannelId / 8U );
	u8_BitOffset = ( byte )( u8_ChannelId % 8U );
	u8_Mask = ( byte )( 0x01U << u8_BitOffset );
	
	if(u8_PortId < en_MAX_NO_OF_PORT ) 
	{
		u8p_PortReg = u8sp_PortDataReg[ u8_PortId ];
		
		if( u8_Level != 0U ){ *u8p_PortReg |= ( byte )u8_Mask; }
  	else{ *u8p_PortReg &= ( byte )( ~u8_Mask ); }
	}
	
	return;
}

/*--------------------------------------------------------------------------*/
/* Function  | Returns the level of all channels of that port               */
/* Name      | TEK_DIO_ReadPort                                             */
/*--------------------------------------------------------------------------*/
/* Parameter | u8_PortId - ID of DIO port                                   */
/* Return    | Level of all channels of that port                           */
/*--------------------------------------------------------------------------*/
byte TEK_DIO_ReadPort( byte u8_PortId )
{
	volatile byte *u8p_PortReg; /* port data register */
	byte u8_PortData = 0U;

	if( u8_PortId < en_MAX_NO_OF_PORT )
	{
		u8p_PortReg = u8sp_PortDataReg[ u8_PortId ];
		u8_PortData = *u8p_PortReg;
	}
		
	return ( u8_PortData );
}

/*--------------------------------------------------------------------------*/
/* Function  | Set a value of a port                                        */
/* Name      | TEK_DIO_WritePort                                            */
/*--------------------------------------------------------------------------*/
/* Parameter | u8_PortId - ID of DIO port                                   */
/*           | u8_Level - Value to be written                               */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
void TEK_DIO_WritePort( byte u8_PortId, byte u8_Level )
{
	volatile byte *u8p_PortReg; /* port data register */

	if( u8_PortId < en_MAX_NO_OF_PORT )
	{
		u8p_PortReg = u8sp_PortDataReg[ u8_PortId ];
		*u8p_PortReg = u8_Level;
	}
	
	return;
}

/*--------------------------------------------------------------------------*/
/* Function  | Reads a subset of the adjoining bits of a port               */
/* Name      | TEK_DIO_ReadChannelGroup                                     */
/*--------------------------------------------------------------------------*/
/* Parameter | st_ChannelGroupId - Pointer to ChannelGroupId                */
/* Return    | DIO port level                                               */
/*--------------------------------------------------------------------------*/
byte TEK_DIO_ReadChannelGroup( const ST_DIO_CH_GROUP_TYPE *st_ChannelGroupId )
{
	volatile byte *u8p_PortReg; /* port data register */
	byte u8_PortId;
	byte u8_Offset;
	byte u8_ChanData;
	byte u8_Mask;
	byte u8_ReadChannelGroupValue = 0U;
	
	u8_PortId = st_ChannelGroupId->u8_mPortId;
	
	if( u8_PortId < en_MAX_NO_OF_PORT )
	{
		u8_Offset = st_ChannelGroupId->u8_mOffset;
		u8_Mask   = st_ChannelGroupId->u8_mMask;
		
		u8p_PortReg = u8sp_PortDataReg[ u8_PortId ];
		u8_ChanData = *u8p_PortReg;
		u8_ReadChannelGroupValue = ( byte )( ( u8_ChanData & u8_Mask ) >> u8_Offset );
	}
	
	return ( u8_ReadChannelGroupValue );
}

/*--------------------------------------------------------------------------*/
/* Function  | set a subset of the adjoining bits of a port to a            */
/*             specified level                                              */
/* Name      | TEK_DIO_WriteChannelGroup                                    */
/*--------------------------------------------------------------------------*/
/* Parameter | st_ChannelGroupId - Pointer to ChannelGroupId                */
/*           | u8_Level - Value to be written                               */
/* Return    | Nothing                                                      */
/*--------------------------------------------------------------------------*/
void TEK_DIO_WriteChannelGroup( const ST_DIO_CH_GROUP_TYPE *st_ChannelGroupId, byte u8_Level )
{
	volatile byte *u8p_PortReg; /* port data register */
	byte u8_PortId;
	byte u8_PinOffset;
	byte u8_ChanData;
	byte u8_Mask;
	
	u8_PortId = st_ChannelGroupId->u8_mPortId;
	
	if( u8_PortId < en_MAX_NO_OF_PORT )
	{
		u8_PinOffset = st_ChannelGroupId->u8_mOffset;
		u8_Mask = st_ChannelGroupId->u8_mMask;
		u8_Level= ( byte )( u8_Level << u8_PinOffset );
		
		u8p_PortReg = u8sp_PortDataReg[ u8_PortId ];
		u8_ChanData = *u8p_PortReg;
		u8_ChanData &= ( byte )( ~u8_Mask );		
		u8_ChanData |= u8_Level;
		*u8p_PortReg = u8_ChanData;
	}
	
	return;
}

/****************************************************************************/
/**                                                                        **/
/**                      LOCAL FUNCTIONS                                   **/
/**                                                                        **/
/****************************************************************************/


#pragma DATA_SEG DEFAULT
#pragma CODE_SEG DEFAULT
/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/
