/*
                             *******************
******************************* C HEADER FILE ********************************
**                           *******************                            **
**                                                                          **
**  Project   : HYUNDAM-FPCM                                                **
**  Filename  : TEK_MCU_Config.H                                            **
**  Version   : -.- (PCB : )                                                **
**  Date      : ----.--.--                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  (c) 2015 TE Connectivity Ltd. All Rights Reserved                       **
**                                                                          **
**                     Tyco Electronics AMP Korea Ltd.                      **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -.-
Date        : ----.--.--
Revised by  : JC.HAM
Description : Original version.

*/

#ifndef _TEK_MCU_CONFIG_INCLUDED
#define _TEK_MCU_CONFIG_INCLUDED

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include "TEK_Lib_Defines.h"

/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/

/*----------------------------------------------------------------------------
  @ MCU configuration - TEK_DIO
----------------------------------------------------------------------------*/

/* Port Configuration ======================================================*/
/* 
 * Note: MC9S12ZVC MUC 
 *  - DDR Register : 0-Associated pin is configured as input, 1-Associated pin is configured as output. 
 *  - PPS Register : If Port set to input 
 *  	0-Pullup device selected; falling edge selected / 1-Pulldown device selected; rising edge selected
 *  - WOM Register : If Port set to output. 
 *  	0-Associated pin operate as push-pull outputs, 1-Associated pin operate as open-drain outputs.
 *  - PER : This bit controls whether a pull device on the associated port input or open-drain output pin is active.
 */

/* Port IN / OUT ===========================================================*/
#define PORT_PIN_IN			( 0U )
#define PORT_PIN_OUT		( 1U )

/* Port E ==================================================================*/
#define PORT_E_0			( PORT_PIN_IN << 0U )	/* output, EXTAL */
#define PORT_E_1			( PORT_PIN_OUT << 1U )	/* output, XTAL */
#define PORT_E_2			( PORT_PIN_OUT << 2U )	/* output, assigned to XX */
#define PORT_E_3			( PORT_PIN_OUT << 3U )	/* output, assigned to XX */
#define PORT_E_4			( PORT_PIN_OUT << 4U )	/* output, assigned to XX */
#define PORT_E_5			( PORT_PIN_OUT << 5U ) 	/* output, assigned to XX */
#define PORT_E_6			( PORT_PIN_OUT << 6U )	/* output, assigned to XX */
#define PORT_E_7			( PORT_PIN_OUT << 7U )	/* output, assigned to XX */

	#define PORT_E_INIT		  	( 0x00U ) 	/* init data */
	#define PORT_E_PT			( 0x00U ) 	/* Port data register */
	/*#define PORT_E_DDR		( 0x00U )*/	/* Port direction register */
	#define PORT_E_PER			( 0x00U ) 	/* Pull device enable register */
	#define PORT_E_PPS			( 0x00U ) 	/* Polarity select register */
	/*#define PORT_E_PIE		( 0x00U )*/	/* Port interrupt enable register */
	/*#define PORT_E_PIF		( 0x00U )*/	/* Port interrupt flag register */
	/*#define PORT_E_DIEN		( 0x00U )*/	/* Digital input enable register */
	/*#define PORT_E_RDR		( 0x00U )*/	/* Reduced Drive Register */
	/*#define PROT_E_WOM		( 0x00U )*/	/* Wired-Or mode register */

/* Port ADH ==================================================================*/
#define PORT_ADH_0			( PORT_PIN_IN << 0U )	/* input,  assigned to Input 4 */
#define PORT_ADH_1			( PORT_PIN_OUT << 1U )	/* output, assigned to XX */
#define PORT_ADH_2			( PORT_PIN_OUT << 2U )	/* output, assigned to XX */
#define PORT_ADH_3			( PORT_PIN_OUT << 3U )	/* output, assigned to XX */
#define PORT_ADH_4			( PORT_PIN_OUT << 4U )	/* output, assigned to XX */
#define PORT_ADH_5			( PORT_PIN_OUT << 5U ) 	/* output, assigned to XX */
#define PORT_ADH_6			( PORT_PIN_OUT << 6U )	/* output, assigned to XX */
#define PORT_ADH_7			( PORT_PIN_OUT << 7U )	/* output, assigned to XX */

	#define PORT_ADH_INIT		( 0x00U ) 	/* init data */
	#define PORT_ADH_PT			( 0x00U ) 	/* Port data register */ 
	/*#define PORT_ADH_DDR		( 0x00U )*/	/* Port direction register */
	#define PORT_ADH_PER		( 0x00U ) 	/* Pull device enable register */
	#define PORT_ADH_PPS		( 0x01U ) 	/* Polarity select register */
	#define PORT_ADH_PIE		( 0x00U ) 	/* Port interrupt enable register */
	#define PORT_ADH_PIF		( 0x00U ) 	/* Port interrupt flag register */
	#define PORT_ADH_DIEN		( 0xFFU ) 	/* Digital input enable register */
	/*#define PORT_ADH_RDR		( 0x00U )*/	/* Reduced Drive Register */
	/*#define PROT_ADH_WOM		( 0x00U )*/	/* Wired-Or mode register */

/* Port ADL ==================================================================*/
#define PORT_ADL_0			( PORT_PIN_IN << 0U )	/* analog input, assigned to Current sense Output 4 */
#define PORT_ADL_1			( PORT_PIN_IN << 1U )	/* analog input, assigned to Current sense Output 3 */
#define PORT_ADL_2			( PORT_PIN_IN << 2U )	/* analog input, assigned to Current sense Output 2 */
#define PORT_ADL_3			( PORT_PIN_IN << 3U )	/* analog input, assigned to Current sense Output 1 */
#define PORT_ADL_4			( PORT_PIN_OUT << 4U )	/* output, assigned to XX */
#define PORT_ADL_5			( PORT_PIN_IN << 5U ) 	/* input,  assigned to Input 1 */
#define PORT_ADL_6			( PORT_PIN_IN << 6U )	/* input,  assigned to Input 2 */
#define PORT_ADL_7			( PORT_PIN_IN << 7U )	/* input,  assigned to Input 3 */

	#define PORT_ADL_INIT		( 0x00U ) 	/* init data */
	#define PORT_ADL_PT			( 0x00U ) 	/* Port data register */ 
	/*#define PORT_ADL_DDR		( 0x00U )*/	/* Port direction register */
	#define PORT_ADL_PER		( 0x00U ) 	/* Pull device enable register */
	#define PORT_ADL_PPS		( 0xE0U ) 	/* Polarity select register */
	#define PORT_ADL_PIE		( 0x00U ) 	/* Port interrupt enable register */
	#define PORT_ADL_PIF		( 0x00U ) 	/* Port interrupt flag register */
	#define PORT_ADL_DIEN		( 0xF0U ) 	/* Digital input enable register */
	/*#define PORT_ADL_RDR		( 0x00U )*/ /* Reduced Drive Register */
	/*#define PROT_ADL_WOM		( 0x00U )*/ /* Wired-Or mode register */

/* Port T ==================================================================*/
#define PORT_T_0			( PORT_PIN_OUT << 0 )	/* output, assigned to Output4 */
#define PORT_T_1			( PORT_PIN_OUT << 1 )	/* output, assigned to Output3 */
#define PORT_T_2			( PORT_PIN_OUT << 2 )	/* output, assigned to Output2 */
#define PORT_T_3			( PORT_PIN_OUT << 3 )	/* output, assigned to Output1 */
#define PORT_T_4			( PORT_PIN_OUT << 4 )	/* output, assigned to XX */
#define PORT_T_5			( PORT_PIN_OUT << 5 ) 	/* output, assigned to XX */
#define PORT_T_6			( PORT_PIN_OUT << 6 )	/* input,  assigned to XX */
#define PORT_T_7			( PORT_PIN_OUT << 7 )	/* input,  assigned to XX */

	#define PORT_T_INIT			( 0x00U ) 	/* init data */
	#define PORT_T_PT			( 0x00U ) 	/* Port data register */ 
	/*#define PORT_T_DDR		( 0x00U )*/	/* Port direction register */
	#define PORT_T_PER			( 0x00U ) 	/* Pull device enable register */
	#define PORT_T_PPS			( 0x00U ) 	/* Polarity select register */
	/*#define PORT_T_PIE		( 0x00U )*/ /* Port interrupt enable register */
	/*#define PORT_T_PIF		( 0x00U )*/ /* Port interrupt flag register */
	/*#define PORT_T_DIEN		( 0x00U )*/ /* Digital input enable register */
	/*#define PORT_T_RDR		( 0x00U )*/ /* Reduced Drive Register */
	/*#define PROT_T_WOM		( 0x00U )*/	/* Wired-Or mode register */

/* Port S ==================================================================*/
#define PORT_S_0			( PORT_PIN_IN << 0U )	/* Input, assigned to SCI Rx */
#define PORT_S_1			( PORT_PIN_OUT << 1U )	/* output, assigned to SCI Tx */
#define PORT_S_2			( PORT_PIN_OUT << 2U )	/* output, assigned to XX */
#define PORT_S_3			( PORT_PIN_OUT << 3U )	/* output, assigned to XX */
#define PORT_S_4			( PORT_PIN_OUT << 4U )	/* output, assigned to XX */
#define PORT_S_5			( PORT_PIN_OUT << 5U ) 	/* output, assigned to XX */
#define PORT_S_6			( PORT_PIN_OUT << 6U )	/* input,  assigned to XX */
#define PORT_S_7			( PORT_PIN_OUT << 7U )	/* input,  assigned to XX */

	#define PORT_S_INIT			( 0x00U ) 	/* init data */
	#define PORT_S_PT			( 0x00U ) 	/* Port data register */ 
	/*#define PORT_S_DDR		( 0x00U )*/	/* Port direction register */
	#define PORT_S_PER			( 0x03U ) 	/* Pull device enable register */
	#define PORT_S_PPS			( 0x00U ) 	/* Polarity select register */
	#define PORT_S_PIE			( 0x00U ) 	/* Port interrupt enable register */
	#define PORT_S_PIF			( 0x00U ) 	/* Port interrupt flag register */
	/*#define PORT_S_DIEN			( 0x00U )*/	/* Digital input enable register */
	/*#define PORT_S_RDR			( 0x00U )*/	/* Reduced Drive Register */
	#define PROT_S_WOM			( 0x00U ) 	/* Wired-Or mode register */

/* Port P ==================================================================*/
#define PORT_P_0			( PORT_PIN_OUT << 0U )	/* output, assigned to XX */
#define PORT_P_1			( PORT_PIN_OUT << 1U )	/* output, assigned to XX */
#define PORT_P_2			( PORT_PIN_OUT << 2U )	/* output, assigned to XX */
#define PORT_P_3			( PORT_PIN_OUT << 3U )	/* output, assigned to XX */
#define PORT_P_4			( PORT_PIN_OUT << 4U )	/* output, assigned to XX */
#define PORT_P_5			( PORT_PIN_OUT << 5U ) 	/* output, assigned to XX */
#define PORT_P_6			( PORT_PIN_OUT << 6U )	/* output, assigned to BTN8982TA-INH */
#define PORT_P_7			( PORT_PIN_OUT << 7U )	/* output, assigned to XX */

	#define PORT_P_INIT			( 0x00U ) 	/* init data */
	#define PORT_P_PT			( 0x00U ) 	/* Port data register */ 
	/*#define PORT_P_DDR		( 0x00U )*/	/* Port direction register */
	#define PORT_P_PER			( 0x00U ) 	/* Pull device enable register */
	#define PORT_P_PPS			( 0x00U ) 	/* Polarity select register */
	#define PORT_P_PIE			( 0x00U ) 	/* Port interrupt enable register */
	#define PORT_P_PIF			( 0x00U ) 	/* Port interrupt flag register */
	/*#define PORT_P_DIEN		( 0x00U )*/	/* Digital input enable register */
	#define PORT_P_RDR			( 0x00U ) 	/* Reduced Drive Register */
	/*#define PROT_P_WOM		( 0x00U )*/	/* Wired-Or mode register */

/* Port J ==================================================================*/
#define PORT_J_0			( PORT_PIN_OUT << 0U )	/* output, assigned to XX */
#define PORT_J_1			( PORT_PIN_OUT << 1U )	/* output, assigned to XX */
#define PORT_J_2			( PORT_PIN_OUT << 2U )	/* output, assigned to XX */
#define PORT_J_3			( PORT_PIN_OUT << 3U )	/* output, assigned to XX */
#define PORT_J_4			( PORT_PIN_OUT << 4U )	/* output, assigned to XX */
#define PORT_J_5			( PORT_PIN_OUT << 5U ) 	/* output, assigned to XX */
#define PORT_J_6			( PORT_PIN_OUT << 6U )	/* input,  assigned to XX */
#define PORT_J_7			( PORT_PIN_OUT << 7U )	/* input,  assigned to XX */

	#define PORT_J_INIT			( 0x00U ) 	/* init data */
	#define PORT_J_PT			( 0x00U ) 	/* Port data register */ 
	/*#define PORT_J_DDR		( 0x00U )*/	/* Port direction register */
	#define PORT_J_PER			( 0x00U ) 	/* Pull device enable register */
	#define PORT_J_PPS			( 0x00U ) 	/* Polarity select register */
	/*#define PORT_J_PIE		( 0x00U )*/ /* Port interrupt enable register */
	/*#define PORT_J_PIF		( 0x00U )*/ /* Port interrupt flag register */
	/*#define PORT_J_DIEN		( 0x00U )*/ /* Digital input enable register */
	/*#define PORT_J_RDR		( 0x00U )*/ /* Reduced Drive Register */
	#define PORT_J_WOM			( 0x00U ) 	/* Wired-Or mode register */

/* Port L ==================================================================*/
#define PORT_L_0			( PORT_PIN_IN << 0U )	/* output, assigned to XX */
#define PORT_L_1			( PORT_PIN_IN << 1U )	/* output, assigned to XX */
#define PORT_L_2			( PORT_PIN_OUT << 2U )	/* output, assigned to XX */
#define PORT_L_3			( PORT_PIN_OUT << 3U )	/* output, assigned to XX */
#define PORT_L_4			( PORT_PIN_OUT << 4U )	/* output, assigned to XX */
#define PORT_L_5			( PORT_PIN_OUT << 5U ) 	/* output, assigned to XX */
#define PORT_L_6			( PORT_PIN_OUT << 6U )	/* input,  assigned to XX */
#define PORT_L_7			( PORT_PIN_OUT << 7U )	/* input,  assigned to XX */

	#define PORT_L_INIT			( 0x00U ) 	/* init data */
	#define PORT_L_PT			( 0x00U ) 	/* Port data register */ 
	/*#define PORT_L_DDR		( 0x00U )*/	/* Port direction register */
	/*#define PORT_L_PER		( 0x00U )*/	/* Pull device enable register */
	#define PORT_L_PPS			( 0x00U ) 	/* Polarity select register */
	#define PORT_L_PIE			( 0x00U ) 	/* Port interrupt enable register */
	#define PORT_L_PIF			( 0x00U ) 	/* Port interrupt flag register */
	#define PORT_L_DIEN			( 0x00U ) 	/* Digital input enable register */
	/*#define PORT_L_RDR		( 0x00U )*/	/* Reduced Drive Register */
	/*#define PROT_L_WOM		( 0x00U )*/	/* Wired-Or mode register */


/*----------------------------------------------------------------------------
  @ MCU configuration - TEK_SPI
----------------------------------------------------------------------------*/
/* SPI module configuration ================================================*/
#define DISABLE_SPI0	/*ENABLE_SPI0*/
#define DISABLE_SPI1
#define DISABLE_SPI2

/* SPI0 configuration (Freescale MC33972) ==================================*/
/*----------------------------------------------------------------------------
  # Interface routing enable/disable
----------------------------------------------------------------------------*/
#define MOD_ROUTE_DI		( 0U )
#define MOD_ROUTE_EN		( 1U )

#define SPI0_ROUTING		( MOD_ROUTE_DI )	  /* module routing */
#define SPI1_ROUTING    	( MOD_ROUTE_DI )	  /* module routing */
/*----------------------------------------------------------------------------
  # BaudRateDivisor = (SPPR+1)*2^(spr+1)
----------------------------------------------------------------------------*/
#define SPI0_BAUDRATE		( 0x42U )			  /* 1Mhz = BUS clock(40Mhz) / 40 */
#define SPI1_BAUDRATE   	( 0x42U )			  /* 1Mhz = BUS clock(40Mhz) / 40 */

#define SPI0_CPOL			( 0U )				  /* 0:active-high, 1:active-low  */
#define SPI1_CPOL			( 0U )				  /* 0:active-high, 1:active-low  */

/*----------------------------------------------------------------------------
  @ SPI clock phase 
----------------------------------------------------------------------------*/
#define CPHA_ODD_EDGE		( 0U )     			/* sampling of data at odd edge(1,3,5,,)  */
#define CPHA_EVEN_EDGE		( 1U )              /* sampling of data at even edge(2,4,6,,) */

#define SPI0_CPHA			( CPHA_EVEN_EDGE )	/* falling edge                 */
#define SPI1_CPHA			( CPHA_EVEN_EDGE )	/* falling edge                 */

/*----------------------------------------------------------------------------
  # SPI data transfer type
----------------------------------------------------------------------------*/
#define MSB_FIRST       	( 0U )
#define LSB_FIRST        	( 1U )

#define SPI0_LSBFE			( MSB_FIRST	)		/* 0:msb first, 1:lsb first     */
#define SPI1_LSBFE			( MSB_FIRST	)		/* 0:msb first, 1:lsb first     */

/*----------------------------------------------------------------------------
  @ MCU configuration - TEK_IEE
----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------
  # if External CLK > 12.8Mhz ECLKDIV = (External CLK(Khz)/8/200Khz) + 0x40
    else                      ECLKDIV = (External CLK(Khz)/200Khz )         
----------------------------------------------------------------------------*/
/* 
 * As Internal EEPROM(D-Flash) of MC9S12ZVC
 *  - Required IEE Clock (0.8Mhz < IEE Clock && IEE Clock < 1Mhz)
 *    @ Internal Bus Clock : 32Mhz (PLL Clock / 2)
 *    @ IEE Clock (0.8Mhz < IEE Clock < 1Mhz) = Internal Bus Clock / FDIV bits in FCLK register
 *                                            = 32Mhz / 31 = 1.03Mhz (This value is recommended by NXP)
 */
#define FKDIV_VALUE   	( 0x1FU )			/* Set up Clock Divider Register */

/*---------------------------------------------------------------------------/
  @ TEK_Eeprom
----------------------------------------------------------------------------*/
#define WL_DATA_SIZE              ( ( byte )( 4U ) )
#define WL_DATA_BUF_SIZE          ( ( byte )( 10U ) )
#define WL_STS_BUF_SIZE           ( ( byte )( 10U ) )

#define WL_DATA_BUF_REAL_SIZE     ( ( byte )( WL_DATA_BUF_SIZE * WL_DATA_SIZE ) )   /* 40 : 10 x 4 */
#define WL_STS_BUF_REAL_SIZE      ( ( byte )( WL_STS_BUF_SIZE * WL_DATA_SIZE ) )    /* 40 : 10 x 4 */
#define WL_TOTAL_REAL_SIZE        ( ( byte )( WL_DATA_BUF_REAL_SIZE + WL_STS_BUF_REAL_SIZE ) )  /* 80 : 40 + 40 */

/*#define WL_DATA_ADDR1             ( ( dword )( 0x00000C00 ) )
#define WL_DATA_ADDR2             ( ( dword )( WL_DATA_ADDR1 + WL_TOTAL_REAL_SIZE ) )*/

#define EEPROM_QUEUE_MAX          ( ( byte )( 120U ) )

#define OSC_CLK_KHZ   (8000)  		/* 8MHz */

#define EEP_SecuritySts_ADDR          ( ( dword )( 0x00000C20U ) )                                /* 0  : C20 */
#define BAK_ALL_DR_LOCK_ADDR          ( ( dword )( EEP_SecuritySts_ADDR + WL_TOTAL_REAL_SIZE ) )  /* 1  : C70 */
#define HAZARD_STAT_ADDR              ( ( dword )( BAK_ALL_DR_LOCK_ADDR + WL_TOTAL_REAL_SIZE ) )  /* 2  : CC0 */
#define LO_BM_STAT_ADDR               ( ( dword )( HAZARD_STAT_ADDR     + WL_TOTAL_REAL_SIZE ) )  /* 3  : D10 */
#define HI_BM_STAT_ADDR               ( ( dword )( LO_BM_STAT_ADDR      + WL_TOTAL_REAL_SIZE ) )  /* 4  : D60 */
#define E_LP_CUT_STAT_ADDR            ( ( dword )( HI_BM_STAT_ADDR      + WL_TOTAL_REAL_SIZE ) )  /* 5  : DB0 */
#define BAK_IgOffTmEng_ADDR           ( ( dword )( E_LP_CUT_STAT_ADDR   + WL_TOTAL_REAL_SIZE ) )  /* 6  : E00 */
#define BAK_FoldMirror_ADDR           ( ( dword )( BAK_IgOffTmEng_ADDR  + WL_TOTAL_REAL_SIZE ) )  /* 7  : E50 */
#define FRT_FOG_STAT_ADDR             ( ( dword )( BAK_FoldMirror_ADDR  + WL_TOTAL_REAL_SIZE ) )  /* 8  : EA0 */
#define RR_FOG_STAT_ADDR              ( ( dword )( FRT_FOG_STAT_ADDR    + WL_TOTAL_REAL_SIZE ) )  /* 9  : EF0 */
#define IG1_STAT_ADDR                 ( ( dword )( RR_FOG_STAT_ADDR     + WL_TOTAL_REAL_SIZE ) )  /* 10 : F40 */
#define ACC_STAT_ADDR                 ( ( dword )( IG1_STAT_ADDR        + WL_TOTAL_REAL_SIZE ) )  /* 11 : F90 */
#define IDUTY_WRITE_ADDR              ( ( dword )( 0x00FD0800U ) ) /* FD0800 */

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/
/*----------------------------------------------------------------------------
  @ MCU configuration - TEK_SPI
----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------
  @ Job configuration
    A Job is composed of one or several channels with the same chip select
    (is not released during the processing of Job).   
----------------------------------------------------------------------------*/
typedef enum
{
	en_SPI_JOB_0 = 0U,	/* MSDI */
	en_SPI_JOB_1,	    /* LSRS */
	en_MAX_NO_OF_JOBS
}EN_SPI_JOB;

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/

#ifndef _TEK_MCU_CONFIG_C_SRC
#endif

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/

#endif

/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/
