/*
                             *******************
******************************* C SOURCE FILE ********************************
**                           *******************                            **
**                                                                          **
**  Project   : TEK                                                         **
**  Filename  : TEK_Lib_Defines.C                                           **
**  Version   : -.- (PCB : )                                                **
**  Date      : ----.--.--                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  (c) 2015 TE Connectivity Ltd. All Rights Reserved                       **
**                                                                          **
**                     Tyco Electronics AMP Korea Ltd.                      **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -.-
Date        : ----.--.--
Revised by  : HK.IM
Description : Original version.

*/

#define _TEK_LIB_DEFINES_C_SRC

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include "TEK_Lib_Defines.h"

/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      PROTOTYPES OF LOCAL FUNCTIONS                     **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      GLOBAL VARIABLES                                  **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/

/*--------------------------------------------------------------------------*/
/* Function  | Count up                                                     */
/* Name      | TEK_U8_CountUp                                               */
/*--------------------------------------------------------------------------*/
/* Parameter | u8_Count, u8_Max                                             */
/* Return    | u8_Count                                                     */
/*--------------------------------------------------------------------------*/
byte TEK_U8_CountUp( byte u8_Count, byte u8_Max )
{
	if( u8_Count < u8_Max )
	{
		u8_Count++;
	}
	else
	{
		if(	u8_Count >= u8_Max )
		{
			u8_Count = u8_Max;
		}
	}
	
	return ( u8_Count );
}

/*--------------------------------------------------------------------------*/
/* Function  | Count down                                                   */
/* Name      | TEK_U8_CountDown                                             */
/*--------------------------------------------------------------------------*/
/* Parameter | u8_Count                                                     */
/* Return    | u8_Count                                                     */
/*--------------------------------------------------------------------------*/
byte TEK_U8_CountDown( byte u8_Count )
{
	if( u8_Count > u8g_CLR )
	{
		u8_Count--;
	}
	else
	{
	  u8_Count = u8g_CLR;
	}
	
	return ( u8_Count );
}

/*--------------------------------------------------------------------------*/
/* Function  | Count up                                                     */
/* Name      | TEK_U16_CountUp                                              */
/*--------------------------------------------------------------------------*/
/* Parameter | u16_Count, u16_Max                                           */
/* Return    | u16_Count                                                    */
/*--------------------------------------------------------------------------*/
word TEK_U16_CountUp( word u16_Count, word u16_Max )
{
	if( u16_Count < u16_Max )
	{
		u16_Count++;
	}
	else
	{
		if(	u16_Count >= u16_Max )
		{
			u16_Count = u16_Max;
		}
	}
	
	return ( u16_Count );
}

/*--------------------------------------------------------------------------*/
/* Function  | Count down                                                   */
/* Name      | TEK_U16_CountDown                                            */
/*--------------------------------------------------------------------------*/
/* Parameter | u16_Count, u16_Max                                           */
/* Return    | u16_Count                                                    */
/*--------------------------------------------------------------------------*/
word TEK_U16_CountDown( word u16_Count )
{
	if( u16_Count > u16g_CLR )
	{
		u16_Count--;
	}
	else
	{
		u16_Count = u16g_CLR;
	}
	
	return ( u16_Count );
}

/*--------------------------------------------------------------------------*/
/* Function  | Count up                                                     */
/* Name      | TEK_U32_CountUp                                              */
/*--------------------------------------------------------------------------*/
/* Parameter | u32_Count, u32_Max                                           */
/* Return    | u32_Count                                                    */
/*--------------------------------------------------------------------------*/
dword TEK_U32_CountUp( dword u32_Count, dword u32_Max )
{
	if( u32_Count < u32_Max )
	{
		u32_Count++;
	}
	else
	{
		if(	u32_Count >= u32_Max )
		{
			u32_Count = u32_Max;
		}
	}
	
	return ( u32_Count );
}

/*--------------------------------------------------------------------------*/
/* Function  | Count down                                                   */
/* Name      | TEK_U32_CountDown                                            */
/*--------------------------------------------------------------------------*/
/* Parameter | u32_Count, u32_Max                                           */
/* Return    | u32_Count                                                    */
/*--------------------------------------------------------------------------*/
dword TEK_U32_CountDown( dword u32_Count )
{
	if( u32_Count > u32g_CLR )
	{
		u32_Count--;
	}
	else
	{
		u32_Count = u32g_CLR;
	}
	
	return ( u32_Count );
}

/*--------------------------------------------------------------------------*/
/* Function  | Detect edge state                                            */
/* Name      | TEK_DetectEdgeState                                          */
/*--------------------------------------------------------------------------*/
/* Parameter | u8_NowValue, *u8p_LastValue                                  */
/* Return    | u8_EdgeSts                                                   */
/*--------------------------------------------------------------------------*/
byte TEK_DetectEdgeState ( byte u8_NowValue, byte *u8p_LastValue )
{
  byte u8_EdgeSts = NO_EDGE;
  
  if ( u8_NowValue != ( *u8p_LastValue ) )
  {
    if ( u8_NowValue != u8g_CLR ) { u8_EdgeSts = HI_EDGE; }
    else { u8_EdgeSts = LO_EDGE; }
    
    *u8p_LastValue = u8_NowValue;
  }
  
  return ( u8_EdgeSts );
}

/****************************************************************************/
/**                                                                        **/
/**                      LOCAL FUNCTIONS                                   **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/
