/*
                             *******************
******************************* C HEADER FILE ********************************
**                           *******************                            **
**                                                                          **
**  Project   : TEK                                                         **
**  Filename  : TEK_Lib_Defines.H                                           **
**  Version   : -.- (PCB : )                                                **
**  Date      : ----.--.--                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  (c) 2015 TE Connectivity Ltd. All Rights Reserved                       **
**                                                                          **
**                     Tyco Electronics AMP Korea Ltd.                      **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -.-
Date        : ----.--.--
Revised by  : HK.IM
Description : Original version.

*/

#ifndef _TEK_LIB_DEFINES_INCLUDED
#define _TEK_LIB_DEFINES_INCLUDED

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include "Defines.h"
  
/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/
/****************************************************************************/
/* @ TEK Library                                                            */
/****************************************************************************/
/*****************************************************************************

signed char ----------- s8
signed char* ---------- s8p
static signed char ---- s8s
static signed char* --- s8sp
extern signed char ---- s8g
extern signed char* --- s8gp

unsigned char --------- u8
unsigned char* -------- u8p
static unsigned char -- u8s
static unsigned char* - u8sp
extern unsigned char -- u8g
extern unsigned char* - u8gp

struct ---------------- st
struct* --------------- stp
static struct --------- sts
static struct* -------- stsp
extern struct --------- stg
extern struct* -------- stgp

enum ------------------ en
static enum ----------- ens
extern enum ----------- eng

*****************************************************************************/
/*****************************************************************************
  @ Types definition
*****************************************************************************/
typedef signed char   sbyte;
#if 0
	typedef unsigned char byte;
#endif

typedef signed int    sword;
#if 0
	typedef unsigned int  word;
#endif
typedef signed long   sdword;
#if 0
	typedef unsigned long dword;
#endif
typedef signed long   sdlong[ 2 ];
#if 0
	typedef unsigned long dlong[ 2 ];
#endif
	
typedef unsigned char bool;	

/*****************************************************************************
  @ Special instruction for MC9S12ZVC of NXP
*****************************************************************************/
#define __DI() \
/*lint -save  -e950 Disable MISRA rule (1.1) checking. */\
                { __asm(sei); }      /* Disable global interrupts  */ \
/*lint -restore Enable MISRA rule (1.1) checking. */
#define __EI() \
/*lint -save  -e950 Disable MISRA rule (1.1) checking. */\
                { __asm(cli); }      /* Enable global interrupts */ \
/*lint -restore Enable MISRA rule (1.1) checking. */
#define EnterCritical() \
/*lint -save  -e950 Disable MISRA rule (1.1) checking. */\
    { __asm(PSH CCL); __asm(SEI); __asm(MOV.B (0,S),u8g_CCR_reg); __asm(LEA S,(1,S)); } /* This macro is used by Processor Expert. It saves CCR register and disable global interrupts. */ \
/*lint -restore Enable MISRA rule (1.1) checking. */
#define ExitCritical() \
/*lint -save  -e950 Disable MISRA rule (1.1) checking. */\
    { __asm(LEA S,(-1,S)); __asm(MOV.B u8g_CCR_reg,(0,S)); __asm(PUL CCL); } /* This macro is used by Processor Expert. It restores CCR register saved in SaveStatusReg(). */ \
/*lint -restore Enable MISRA rule (1.1) checking. */
/* obsolete definition for backward compatibility */
#define SaveStatusReg()     EnterCritical()
#define RestoreStatusReg()  ExitCritical()
#define PE_DEBUGHALT() \
/*lint -save  -e950 Disable MISRA rule (1.1) checking. */\
    { asm(BGND); }                     /* This macro forces entering to background debug mode, if enabled, and execute a sw breakpoint */ \
/*lint -restore Enable MISRA rule (1.1) checking. */

extern volatile byte u8g_CCR_reg;          /* Current CCR register */

/*****************************************************************************
  @ Watch dog definition
*****************************************************************************/
#if defined ( ENABLE_INTERNAL_WATCH_DOG )
#define WatchDog_Clear()    { ARMCOP = 0x55; ARMCOP = 0xAA; }
#endif

/*****************************************************************************
  @ Standard Defines                                                       
*****************************************************************************/
#ifndef NULL
#define NULL                   ( ( void* ) 0 )
#endif

/* Bits peripheral register access macros - 8 bit access */  
#define setReg8( RegName, val )                     ( RegName = ( byte )( val ) )
#define getReg8( RegName )                          ( ( byte )RegName )
#define testReg8Bits( RegName, GetMask )            ( RegName & ( GetMask ) )
#define clrReg8Bits( RegName, ClrMask )             ( RegName &= ( byte )( ~ClrMask & 0xFFU ) )
#define setReg8Bits( RegName, SetMask )             ( RegName |= ( byte )( SetMask ) )
#define invertReg8Bits( RegName, InvMask )          ( RegName ^= ( byte )( InvMask ) )
#define clrSetReg8Bits( RegName, ClrMask, SetMask ) ( RegName = ( RegName & ( ( byte )( ~ClrMask & 0xFFU ) ) ) | ( byte )( SetMask ) )

/* Bits peripheral register access macros - 16 bit access */  
#define setReg16( RegName, val )                    ( RegName = ( word )( val ) )                                                                         
#define getReg16( RegName )                         ( ( word )RegName )
#define testReg16Bits( RegName, GetMask )           ( RegName & ( GetMask ) )
#define clrReg16Bits( RegName, ClrMask )            ( RegName &= ( word )( ~ClrMask & 0xFFFFU ) )
#define setReg16Bits( RegName, SetMask )             ( RegName |= ( word )( SetMask ) )
#define invertReg16Bits( RegName, InvMask )          ( RegName ^= ( word )( InvMask ) )
#define clrSetReg16Bits( RegName, ClrMask, SetMask ) ( RegName = ( RegName & ( ( word )( ~ClrMask & 0xFFFFU ) ) ) | ( word )( SetMask ) )

/* Data assemble/deassemble macros */
/* compose from byte stream a 16 bit data */
#define Make16Bit( hiByte, loByte )                           ( ( word )( ( ( ( word )( hiByte ) ) << 8 ) | \
                                                                            ( ( word )( loByte) ) ) )
/* compose from byte stream a 32 bit data */
#define Make32Bit( hiHiByte, hiLoByte, loHiByte, loLoByte )   ( ( dword )( ( ( ( dword )( hiHiByte ) ) << 24 ) | \
                                                                           ( ( ( dword )( hiLoByte ) ) << 16 ) | \
                                                                           ( ( ( dword )( loHiByte ) ) << 8 )  | \
                                                                             ( ( dword )( loLoByte ) ) ) )

/* decompose 8 bit data in nibble stream */
#define Get8BitHiNibble( data )                               ( ( byte )( ( data & 0xF0U ) >> 8 ) )
#define Get8BitLoNibble( data )                               ( ( byte )( ( data & 0x0FU ) ) )

/* decompose 16 bit data in byte stream */
#define Get16BitHiByte( data )                                ( ( byte )( ( ( word )( data ) ) >> 8 ) )
#define Get16BitLoByte( data )                                ( ( byte )( data ) )

/* decompose 32 bit data in byte stream */
#define Get32BitHiHiByte( data )                              ( ( byte )( ( ( dword )( data ) ) >> 24 ) )
#define Get32BitHiLoByte( data )                              ( ( byte )( ( ( dword )( data ) ) >> 16 ) )
#define Get32BitLoHiByte( data )                              ( ( byte )( ( ( dword )( data ) ) >> 8 ) )
#define Get32BitLoLoByte( data )                              ( ( byte )( data ) )

/* decompose 32 bit data in word stream */
#define Get32BitHiWord( data )                                ( ( word )( ( ( dword )( data ) ) >> 16 ) )
#define Get32BitLoWord( data )                                ( ( word )( data ) )

/* Little endian <==> big endian 32-bit swap macros. */
#define Swap32LittleBig( a ) {                                  \
          dword u32_Tmp;                                        \
          u32_Tmp = a;                                          \
          ( ( byte * )&a )[ 0 ] = ( ( byte * )&u32_Tmp )[ 3 ];  \
          ( ( byte * )&a )[ 1 ] = ( ( byte * )&u32_Tmp )[ 2 ];  \
          ( ( byte * )&a )[ 2 ] = ( ( byte * )&u32_Tmp )[ 1 ];  \
          ( ( byte * )&a )[ 3 ] = ( ( byte * )&u32_Tmp )[ 0 ];  \
        }

/* Little endian <==> big endian 16-bit swap macros. */
#define Swap16LittleBig( a ) {                                  \
          word u16_Tmp;                                         \
          u16_Tmp = ( word )a;                                  \
          ( ( byte * )&a )[ 0 ] = ( ( byte * )&u16_Tmp )[ 1 ];  \
          ( ( byte * )&a )[ 1 ] = ( ( byte * )&u16_Tmp )[ 0 ];  \
        }

#define MAX( a, b )         ( ( a ) > ( b ) ? ( a ) : ( b ) )
#define MIN( a, b )         ( ( a ) < ( b ) ? ( a ) : ( b ) )

#define ABS( a )            ( ( a ) > 0 ? ( a ) : ( -( a ) ) )

#define SWAP( a, b )        ( ( a ) ^= ( b ), ( b ) ^= ( a ), ( a ) ^= ( b ) )

#define ASCII2HEX( a )      ( ( a ) - ( ( a ) > '9' ? ( 'A' - 10 ) : '0' ) )
#define HEX2ASCII( b )      ( ( b ) + ( ( b ) >  9  ? ( 'A' - 10 ) : '0' ) )

#define UPPERCASE( c )      ( ( c ) - ( ( 'a' <= ( c ) && ( c ) <= 'z' ) ? ( 'a' - 'A' ) : 0 ) )     
#define LOWERCASE( c )      ( ( c ) + ( ( 'A' <= ( c ) && ( c ) <= 'Z' ) ? ( 'a' - 'A' ) : 0 ) )

#define ARRAY_SIZE(array)   ( sizeof( array ) / sizeof( array[ 0 ] ) )

/* Bits mask */
#define u8g_Bit0    ( 0x01U ) /* Bit0 */ 
#define u8g_Bit1    ( 0x02U )	/* Bit1 */ 
#define u8g_Bit2    ( 0x04U )	/* Bit2 */ 
#define u8g_Bit3    ( 0x08U )	/* Bit3 */ 
#define u8g_Bit4    ( 0x10U )	/* Bit4 */ 
#define u8g_Bit5    ( 0x20U )	/* Bit5 */ 
#define u8g_Bit6    ( 0x40U )	/* Bit6 */ 
#define u8g_Bit7    ( 0x80U )	/* Bit7 */

/* mask bits */
#define u8g_MkBit1  ( 0x01U )	/* Bit1 */ 
#define u8g_MkBit2  ( 0x03U )	/* Bit2 */ 
#define u8g_MkBit3  ( 0x07U )	/* Bit3 */ 
#define u8g_MkBit4  ( 0x0FU )	/* Bit4 */ 
#define u8g_MkBit5  ( 0x1FU )	/* Bit5 */ 
#define u8g_MkBit6  ( 0x3FU )	/* Bit6 */ 
#define u8g_MkBit7  ( 0x7FU )	/* Bit7 */
#define u8g_MkBit8  ( 0xFFU )	/* Bit8 */

/* Bit shift */
#define	SFT00		    ( 0U )    /* initial shift value */
#define	SFT01		    ( 1U )		/* initial shift value */
#define	SFT02		    ( 2U )		/* initial shift value */
#define	SFT03		    ( 3U )		/* initial shift value */
#define	SFT04		    ( 4U )		/* initial shift value */
#define	SFT05		    ( 5U )		/* initial shift value */
#define	SFT06		    ( 6U )		/* initial shift value */
#define	SFT07		    ( 7U )		/* initial shift value */
#define	SFT08		    ( 8U )		/* initial shift value */
#define	SFT16		    ( 16U )	  /* initial shift value */

/* Macros for sleep ready */
#define SLEEP_READY     ( ( byte )( 0x00 ) )		/* Sleep Available, OK */
#define	SLEEP_NA				( ( byte )( 0x01 ) )		/* bit0 : Appl Sleep Not Available */

/* Macros for edge state type */
#define NO_EDGE         ( ( byte )( 0U ) )
#define LO_EDGE         ( ( byte )( 1U ) )
#define HI_EDGE         ( ( byte )( 2U ) )

/*****************************************************************************
  @ Macros for unsigned 1bit variable(bit field)                                                    
*****************************************************************************/
#define	big_TRUE      	( ( byte )( 1U ) )
#define	big_FALSE		( ( byte )( 0U ) )

#define	big_ON        	( ( byte )( 1U ) )
#define	big_OFF			( ( byte )( 0U ) )

#define	big_NA			( ( byte )( 1U ) )     /* Not Available */
#define	big_OK			( ( byte )( 0U ) )

#define	big_HI			( ( byte )( 1U ) )     /* value high */
#define	big_LO			( ( byte )( 0U ) )		  /* value low  */

#define	big_ENA			( ( byte )( 1U ) )		  /* enable  */
#define	big_DIS			( ( byte )( 0U ) )		  /* disable */

#define big_ACTIVE    	( ( byte )( 1U ) )
#define big_INACTIVE  	( ( byte )( 0U ) )

#define	big_SET			  ( ( byte )( 1U ) )		  /* SET Value = 1   */
#define	big_RESET		  ( ( byte )( 0U ) )		  /* RESET Value = 0 */

#define u8g_MAX			  ( ( byte )( 0xFFU ) )
#define	u8g_MIN			  ( ( byte )( 0x00U ) )

#define	u16g_MAX		  ( ( word )( 0xFFFFU ) )
#define	u16g_MIN		  ( ( word )( 0x0000U ) )

#define	u32g_MAX		  ( ( word )( 0xFFFFFFFFUL ) )
#define	u32g_MIN		  ( ( word )( 0x00000000UL ) )

#define u8g_HI			  ( ( byte )( 0x01U ) )  /* value high */
#define	u8g_LO			  ( ( byte )( 0x00U ) )	/* value low */

#define	u8g_ON			  ( ( byte )( 0x01U ) )	/* General On */
#define	u8g_OFF			  ( ( byte )( 0x00U ) )	/* General Off */

#define u8g_SET       		( ( byte )( 0x01U ) )
#define u8g_CLR       		( ( byte )( 0x00U ) )

#define	u16g_SET		  ( ( word )( 0x0001U ) )
#define	u16g_CLR		  ( ( word )( 0x0000U ) )

#define	u32g_SET		  ( ( dword )( 0x00000001U ) )
#define	u32g_CLR		  ( ( dword )( 0x00000000U ) ) 

/*****************************************************************************
  @ Internal definitions of the error constants.                           
*****************************************************************************/
#define ERR_OK           ( 0U )  /* OK */
#define ERR_SPEED        ( 1U )  /* This device does not work in the active speed mode. */
#define ERR_RANGE        ( 2U )  /* Parameter out of range. */
#define ERR_VALUE        ( 3U )  /* Parameter of incorrect value. */
#define ERR_OVERFLOW     ( 4U )  /* Timer overflow. */
#define ERR_MATH         ( 5U )  /* Overflow during evaluation. */
#define ERR_ENABLED      ( 6U )  /* Device is enabled. */
#define ERR_DISABLED     ( 7U )  /* Device is disabled. */
#define ERR_BUSY         ( 8U )  /* Device is busy. */
#define ERR_NOTAVAIL     ( 9U )  /* Requested value or method not available. */
#define ERR_RXEMPTY      ( 10U ) /* No data in receiver. */
#define ERR_TXFULL       ( 11U ) /* Transmitter is full. */
#define ERR_BUSOFF       ( 12U ) /* Bus not available. */
#define ERR_OVERRUN      ( 13U ) /* Overrun error is detected. */
#define ERR_FRAMING      ( 14U ) /* Framing error is detected. */
#define ERR_PARITY       ( 15U ) /* Parity error is detected. */
#define ERR_NOISE        ( 16U ) /* Noise error is detected. */
#define ERR_IDLE         ( 17U ) /* Idle error is detected. */
#define ERR_FAULT        ( 18U ) /* Fault error is detected. */
#define ERR_BREAK        ( 19U ) /* Break char is received during communication. */
#define ERR_CRC          ( 20U ) /* CRC error is detected. */
#define ERR_ARBITR       ( 21U ) /* A node losts arbitration. This error occurs if two nodes start transmission at the same time. */
#define ERR_PROTECT      ( 22U ) /* Protection error is detected. */
#define ERR_UNDERFLOW    ( 23U ) /* Underflow error is detected. */
#define ERR_UNDERRUN     ( 24U ) /* Underrun error is detected. */
#define ERR_COMMON       ( 25U ) /* Common error of a device. */
#define ERR_LINSYNC      ( 26U ) /* LIN synchronization error is detected. */

/*****************************************************************************
  @ Debug Macro
*****************************************************************************/
/* Mode */
#define ANSI_SCREEN_REVERSE 	"\x1b[?5h"
#define ANSI_SCREEN_NORMAL		"\x1b[?5l"

/* Character Attributes */
#define ANSI_CLEAR		        "\x1b[0m\x7"
#define ANSI_BOLD		        "\x1b[1m"
#define ANSI_UNDERSCORE	      	"\x1b[4m"
#define ANSI_BLINK		        "\x1b[5m"
#define ANSI_REVERSE	        "\x1b[7m"

/* Character Color */
#define ANSI_RED  		        "\x1b[0;31m"
#define ANSI_L_RED 		        "\x1b[1;31m"
#define ANSI_GREEN		        "\x1b[0;32m"
#define ANSI_L_GREEN	        "\x1b[1;32m"
#define ANSI_YELLOW		        "\x1b[0;33m"
#define ANSI_L_YELLOW	        "\x1b[1;33m"
#define ANSI_BLUE 		        "\x1b[0;34m"
#define ANSI_L_BLUE 	        "\x1b[1;34m"
#define ANSI_MAGENTA 	        "\x1b[0;35m"
#define ANSI_L_MAGENTA        	"\x1b[1;35m"
#define ANSI_CYAN 		        "\x1b[0;36m"
#define ANSI_L_CYAN 	        "\x1b[1;36m"
#define ANSI_L_WHITE 	        "\x1b[1;37m"

/* Control Character */
#define ANSI_BELL		        "\x7"
#define MAX_COLOR	            ( 13 )

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/

#ifndef _TEK_LIB_DEFINES_C_SRC
#endif

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/
extern byte TEK_U8_CountUp( byte u8_Count, byte u8_Max );
extern byte TEK_U8_CountDown( byte u8_Count );
extern word TEK_U16_CountUp( word u16_Count, word u16_Max );
extern word TEK_U16_CountDown( word u16_Count );
extern dword TEK_U32_CountUp( dword u32_Count, dword u32_Max );
extern dword TEK_U32_CountDown( dword u32_Count );
extern byte TEK_DetectEdgeState ( byte u8_NowValue, byte *u8p_LastValue );

#endif

/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/
