/*
                             *******************
******************************* C SOURCE FILE ********************************
**                           *******************                            **
**                                                                          **
**  project   : TE Smart Relay Module for TE                                **
**  filename  : Main.c                                                      **
**  version   : 1.00 (PCB 1.00)                                             **
**  date      : - --, ----                                                  **
**                                                                          **
******************************************************************************
**                                                                          **
**  Copyright (c) 2016, TE Korea.                                            **
**  All rights reserved.                                                    **
**                                                                          **
**                    TE Connectivity KOREA LTD                             **
**                          - SUWON R&D CENTER -                            **
******************************************************************************

VERSION HISTORY:
----------------

Version     : -
Date        : - --, ----
Revised by  : TE Korea.
Description : Original version.
*/

/****************************************************************************/
/**                                                                        **/
/**                      MODULES USED                                      **/
/**                                                                        **/
/****************************************************************************/
#include <hidef.h> 		/* for EnableInterrupts macro */
#include "main.h"

/**** TEK Library include ****/
#include "TEK_MCU_Layer.h"
#include "TEK_ECU_Layer.h"

/**** Appl layer include ****/

#pragma CODE_SEG __NEAR_SEG NON_BANKED
#pragma CODE_SEG DEFAULT

/****************************************************************************/
/**                                                                        **/
/**                      DEFINITIONS AND MACROS                            **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      TYPEDEFS AND STRUCTURES                           **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      PROTOTYPES OF LOCAL FUNCTIONS                     **/
/**                                                                        **/
/****************************************************************************/
static void Low_Level_Init(void);
static void TimerInt_Init( void );
static void SystemReset(void) ;
static void Cpu_OnReset(void) ;

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED VARIABLES                                **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      GLOBAL VARIABLES                                  **/
/**                                                                        **/
/****************************************************************************/
volatile byte u8g_CCR_reg;          /* Current CCR register */

byte eg_u8Tmain;
byte eg_u8TmainCnt;
byte eg_u8EngineMode;
byte eg_u16MainTaskCnt;

//tdsVehicleOptions eg_tdsVehicleOptions;

/****************************************************************************/
/**                                                                        **/
/**                      EXPORTED FUNCTIONS                                **/
/**                                                                        **/
/****************************************************************************/

/****************************************************************************/
/**                                                                        **/
/**                      LOCAL FUNCTIONS                                   **/
/**                                                                        **/
/****************************************************************************/
int main(void) 
{
	static byte ls_u8Flags = 0U;
	
	/* Global interrupt disable */
	DisableInterrupts
	
	eg_u16MainTaskCnt = 0U;
   
	/*----------------------------------------------------------------------*/
	/* System layer initialization                                          */
	/*----------------------------------------------------------------------*/
	Low_Level_Init(); /* Vector base address, Clock(PLL), etc.. */
	
	/*----------------------------------------------------------------------*/
	/* MCU layer initilaization                                             */
	/*----------------------------------------------------------------------*/
	TEK_DIO_Init();
	TEK_ADC_Init();
	TimerInt_Init();

	/*----------------------------------------------------------------------*/
	/* ECU layer initilaization                                                          */
	/*----------------------------------------------------------------------*/
	TEK_AnalogToDigital_Init();
		
	/*----------------------------------------------------------------------*/
	/* SERVICE layer initilaization                                                     */
	/*----------------------------------------------------------------------*/

	/*----------------------------------------------------------------------*/
	/* Application layer initilaization                                                 */
	/*----------------------------------------------------------------------*/

	/*----------------------------------------------------------------------*/
	/* COMM layer initilaization                                                       */
	/*----------------------------------------------------------------------*/
	
	/*----------------------------------------------------------------------*/
	/* Other initilaization                                       */
	/*----------------------------------------------------------------------*/
	
	/* Global interrupt enable */
	EnableInterrupts

	for(;;) 
	{
		__RESET_WATCHDOG();		/* feeds the dog */
		/*------------------------------------------------------------------*/
		/* Check K-Line commands                                   */
		/*------------------------------------------------------------------*/      
				
		if( eg_u8Tmain == big_SET )				/* 5msec Task */ 
		{
			eg_u8Tmain = big_RESET;
		
			TEK_AnalogToDigital_Main();			/* ADC conversion start for all ADC channels & Update result buffer. / run-time : around 62usec */ 
		}
	}
	
	return ( (word) 0U );
}

/****************************************************************************/                                                                                                                          
/* Function  | Start up Init                                                */                                                                                                                          
/* Name      | Low_Level_Init                                               */                                                                                                                          
/*--------------------------------------------------------------------------*/                                                                                                                          
/* Parameter | Nothing                                                      */                                                                                                                          
/* Return    | Nothing                                                      */                                                                                                                          
/****************************************************************************/
static void Low_Level_Init(void)
{
	/* ### MC9S12ZVC192_64 "Cpu" init code ... */
	/*  PE initialization code after reset */
	/* IVBR: IVB_ADDR=0x7FFF,??=0 */
	setReg16(IVBR, 0xFFFEU); 	/* FF-FE10 ~ FFF8 */           
	/* ECLKCTL: NECLK=1,??=0,??=0,??=0,??=0,??=0,??=0,??=0 */
	setReg8(ECLKCTL, 0x80U);	/* Disable ECLK output */              
	/*  System clock initialization */
	/* CPMUPROT: ??=0,??=0,??=1,??=0,??=0,??=1,??=1,PROT=0 */
	/* Writing 0x26 to the CPMUPROT register clears the PROT bit, other write accesses set the PROT bit. */
	setReg8(CPMUPROT, 0x26U);       /* Disable protection of clock configuration registers */ 
	/* CPMUCLKS: PSTP=0 */
	clrReg8Bits(CPMUCLKS, 0x40U);         
	/* CPMUCLKS: PLLSEL=1 */
	setReg8Bits(CPMUCLKS, 0x80U);        /* Enable the PLL to allow write to divider registers */ 
	/* CPMUPOSTDIV: ??=0,??=0,??=0,POSTDIV4=0,POSTDIV3=0,POSTDIV2=0,POSTDIV1=0,POSTDIV0=0 */
	setReg8(CPMUPOSTDIV, 0x00U);         /* Set the post divider register */ 
	/* Whenever changing PLL reference clock (REFCLK) frequency to a higher value
	it is recommended to write CPMUSYNR = 0x00 in order to stay within specified
	maximum frequency of the MCU */
	/* CPMUSYNR: VCOFRQ1=0,VCOFRQ0=0,SYNDIV5=0,SYNDIV4=0,SYNDIV3=0,SYNDIV2=0,SYNDIV1=0,SYNDIV0=0 */
	setReg8(CPMUSYNR, 0x00U);            /* Set the multiplier register */ 
	/* CPMUREFDIV: REFFRQ1=1,REFFRQ0=1,??=0,??=0,REFDIV3=0,REFDIV2=0,REFDIV1=0,REFDIV0=0 */
	setReg8(CPMUREFDIV, 0xC0U);          /* Set the divider register */ 
	/* CPMUOSC2: ??=0,??=0,??=0,??=0,??=0,??=0,OMRE=1,OSCMOD=0 */
	setReg8(CPMUOSC2, 0x02U);            /* Configure external oscillator options */ 
	/* CPMUOSC: OSCE=1,??=0,??=0,??=0,??=0,??=0,??=0,??=0 */
	setReg8(CPMUOSC, 0x80U);             /* Enable the oscillator */ 
	/* CPMUPLL: ??=0,??=0,FM1=0,FM0=0,??=0,??=0,??=0,??=0 */
	setReg8(CPMUPLL, 0x00U);             /* Set the PLL frequency modulation */ 
	/* CPMUSYNR: VCOFRQ1=0,VCOFRQ0=1,SYNDIV5=0,SYNDIV4=0,SYNDIV3=0,SYNDIV2=0,SYNDIV1=0,SYNDIV0=1 */
	setReg8(CPMUSYNR, 0x41U);            /* Set the multiplier register */ 
	while(CPMUIFLG_UPOSC == 0U) {        /* Wait until the oscillator is qualified by the PLL */
	}
	/* CPMUPROT: ??=0,??=0,??=0,??=0,??=0,??=0,??=0,PROT=0 */
	setReg8(CPMUPROT, 0x00U);            /* Enable protection of clock configuration registers */ 
	/* CPMUCOP: RSBCK=0,WRTMASK=1 */
	clrSetReg8Bits(CPMUCOP, 0x40U, 0x20U); 
	/* CPMUHTCTL: ??=0,??=0,VSEL=0,??=0,HTE=0,HTDS=0,HTIE=1,HTIF=0 */
	setReg8(CPMUHTCTL, 0x02U);            
	/* CPMUVREGCTL: ??=0,??=0,??=0,??=0,??=0,EXTCON=1,EXTXON=0,INTXON=1 */
	setReg8(CPMUVREGCTL, 0x05U);          
	/*** End of PE initialization code after reset ***/

	/* Int. priority initialization */
	/*                                        No. Address Pri XGATE Name                 Description */
	setReg8(INT_CFADDR, 0x38U);           
	setReg8(INT_CFDATA7, 0x01U);         /*  0x3F  0x00FFFEFC   1   -    ivVhti               used by PE */ 
	setReg8(INT_CFADDR, 0x40U);           
	setReg8(INT_CFDATA1, 0x01U);         /*  0x41  0x00FFFF04   1   no   ivVlvi               used by PE */ 
	setReg8(INT_CFADDR, 0x70U);           
	setReg8(INT_CFDATA3, 0x04U);         /*  0x73  0x00FFFFCC   4   no   ivVtim0ch0           used by PE */ 
	/* Common initialization of the CPU registers */
	/* TIM0TSCR1: TEN=0,TSWAI=0,TSFRZ=0,TFFCA=0,PRNT=1,??=0,??=0,??=0 */
	setReg8(TIM0TSCR1, 0x08U);            
	/* TIM0OCPD: OCPD7=1,OCPD6=1,OCPD5=1,OCPD4=1,OCPD3=1,OCPD2=1,OCPD1=1,OCPD0=1 */
	/* OCPD "1" Disables the timer channel port. Output Compare action will not occur on the channel pin, but the output compare flag still become set.*/
	setReg8(TIM0OCPD, 0xFFU);             
	/* TIM0PACTL: CLK1=0,CLK0=0 */
	clrReg8Bits(TIM0PACTL, 0x0CU);        
	/* TIM0OC7M: OC7M0=0 */
	clrReg8Bits(TIM0OC7M, 0x01U);         
	/* TIM0TIOS: IOS7=1,IOS0=1 */
	setReg8Bits(TIM0TIOS, 0x81U);         
	/* TIM0TCTL2: OM0=0,OL0=0 */
	clrReg8Bits(TIM0TCTL2, 0x03U);        
	/* TIM0TTOV: TOV7=0,TOV0=0 */
	clrReg8Bits(TIM0TTOV, 0x81U);         
	/* TIM0TCTL1: OM7=0,OL7=0 */
	clrReg8Bits(TIM0TCTL1, 0xC0U);        
	/* TIM0TSCR2: TOI=0,TCRE=1 */
	clrSetReg8Bits(TIM0TSCR2, 0x80U, 0x08U); 
	/* TIM0TFLG1: C7F=1,C6F=1,C5F=1,C4F=1,C3F=1,C2F=1,C1F=1,C0F=1 */
	setReg8(TIM0TFLG1, 0xFFU);            
	/* TIM0TIE: C0I=1 */
	setReg8Bits(TIM0TIE, 0x01U);          
	/* TIM0PTPSR: PTPS7=0,PTPS6=0,PTPS5=0,PTPS4=0,PTPS3=0,PTPS2=0,PTPS1=0,PTPS0=0 */
	setReg8(TIM0PTPSR, 0x00U);            
	/* CPMUINT: LOCKIE=0,OSCIE=0 */
	clrReg8Bits(CPMUINT, 0x12U);          
	/* CPMULVCTL: LVIE=1 */
	setReg8Bits(CPMULVCTL, 0x02U);        
	/* ECCIE: SBEEIE=0 */
	clrReg8Bits(ECCIE, 0x01U);            
	/* ECCDCMD: ECCDRR=0 */
	clrReg8Bits(ECCDCMD, 0x80U);          
	/* RDRP: RDRP6=0,RDRP5=0,RDRP4=0,RDRP2=0,RDRP0=0 */
	clrReg8Bits(RDRP, 0x75U);             
	/* IRQCR: IRQEN=0 */
	clrReg8Bits(IRQCR, 0x40U);     
	
	/******************************************************/
	/* Module Routing Register Configuration */
	/******************************************************/
	setReg8Bits(MODRR0, 0x10U);		/* SCI0 Port routing - routing to PS0 and PS1 */
	setReg8Bits(MODRR2, 0x88U);		/* PWM Port routing - routing to PT3 and PT2 */
	
	/* ### MC9S12ZVC192_64 "Cpu" init code ... */
	Cpu_OnReset();

	return;
}

/****************************************************************************/                                                                                                                          
/* Function  | Timer Setup / 125usec or 1msec                               */                                                                                                                          
/* Name      | TimerInt_Init                                                */                                                                                                                          
/*--------------------------------------------------------------------------*/                                                                                                                          
/* Parameter | Nothing                                                      */                                                                                                                          
/* Return    | Nothing                                                      */                                                                                                                          
/****************************************************************************/
static void TimerInt_Init( void )
{
#if 0	/* 125usec timer interrupt setting */	
	/* TIM0TC0: BIT=0x0FA0 */
	setReg16(TIM0TC0, 0x0FA0U);          /* Store given value to the compare register */ 
	/* TIM0TC7: BIT=0x0FA0 */
	setReg16(TIM0TC7, 0x0FA0U);          /* Store given value to the modulo register */
#else	/* 1msec timer interrupt setting */
	/* TIM0TC0: BIT=0x7D00 */
	setReg16(TIM0TC0, 0x7D00U);          /* Store given value to the compare register */ 
	/* TIM0TC7: BIT=0x7D00 */
	setReg16(TIM0TC7, 0x7D00U);          /* Store given value to the modulo register */ 	
#endif
	
	TIM0TIE_C0I = 1U;                    /* Enable interrupt */ 
	TIM0TSCR1_TEN = 1U;                  /* Start timer */ 	
	
   return;
}

/****************************************************************************/                                                                                                                          
/* Function  | Reset Control                                                */                                                                                                                          
/* Name      | SystemReset                                                  */                                                                                                                          
/*--------------------------------------------------------------------------*/                                                                                                                          
/* Parameter | Nothing                                                      */                                                                                                                          
/* Return    | Nothing                                                      */                                                                                                                          
/****************************************************************************/
static void SystemReset(void)
{
   /* watchdog enable (524.288ms at 8Mhz OSC) */
   for(;;){}
   /* while(1){} */
}

/*
** ===================================================================
**     Event       :  Cpu_OnReset (module Events)
**
**     Component   :  Cpu [MC9S12ZVC192_64]
**     Description :
**         This software event is called after reset.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
/****************************************************************************/                                                                                                                          
/* Function  | Cpu_OnReset (module Events)                                  */                                                                                                                          
/* Name      |                                                              */                                                                                                                          
/*--------------------------------------------------------------------------*/                                                                                                                          
/* Parameter | None                                                         */                                                                                                                          
/* Return    | Nothing                                                      */                                                                                                                          
/****************************************************************************/
static void Cpu_OnReset(void)
{
  /* Write your code here ... */
}

#pragma CODE_SEG DEFAULT

/****************************************************************************/                                                                                                                          
/* Function  | Cpu_Delay10US/100US                                          */                                                                                                                          
/* Name      | Cpu_Delay10US                                                */                                                                                                                          
/*--------------------------------------------------------------------------*/                                                                                                                          
/* Parameter | Nothing                                                      */                                                                                                                          
/* Return    | Nothing                                                      */                                                                                                                          
/****************************************************************************/
#pragma CODE_SEG __NEAR_SEG NON_BANKED
#pragma NO_ENTRY
#pragma NO_EXIT
//#pragma MESSAGE DISABLE C5703
//#pragma MESSAGE DISABLE C4201
//#pragma PRQA_MESSAGES_OFF
void Cpu_Delay100US(word us100)
{
  /* irremovable overhead (ignored): 6.5 cycles */
  /* jsr:  2.5 cycles overhead (call this function) */
  /* LD D2,#x:  1 cycles overhead (load parameter into register) */
  /* rts:  3 cycles overhead (return from this function) */

  /* irremovable overhead for each 100us cycle (counted): 2.5 cycles */
  /* dbne:  4.5 cycles overhead */

  /*lint -save  -e950 -e522 Disable MISRA rule (1.1,14.2) checking. */
  asm {
    loop:
    /* 100 us delay block begin */
    /*
     * Delay
     *   - requested                  : 100 us @ 32MHz,
     *   - possible                   : 3200 c, 100000 ns
     *   - without removable overhead : 3195.5 c, 99859.38 ns
     */
    LD D6,#0x0246                      /* (1_5 c: 46.88 ns) number of iterations */
label0:
    DEC D6                             /* (1 c: 31.25 ns) decrement d1 */
    BNE label0                         /* (4 c: 125 ns) repeat 582x */
    /* 100 us delay block end */
    DBNE D2, loop                      /* us100 parameter is passed via D register */
  };
}
//#pragma PRQA_MESSAGES_ON
//#pragma MESSAGE DEFAULT
#pragma CODE_SEG DEFAULT
/****************************************************************************/
/**                                                                        **/
/**                      EOF                                               **/
/**                                                                        **/
/****************************************************************************/

